@@ -6,13 +6,13 @@ check_pkg() {
 	pkgname=$1
 	add_define=$2
 	atleast_version=$3
-	echo -n "Checking for package ${pkgname}... "
+	printf "Checking for package ${pkgname}... "
 	if pkg-config --silence-errors "${pkgname}" ; then
 		echo "found"
 		if [ -n "$atleast_version" ] ; then
 			if ! pkg-config --atleast-version=$atleast_version ${pkgname} ; then
 				echo "at least ${pkgname} $atleast_version required."
-				exit 1
+				return 1
 			fi
 		fi
 		echo "# configuration for package ${pkgname}" >> config.mk
@@ -36,7 +36,7 @@ check_custom() {
 	pkgname=$1
 	customconfig=$2
 	add_define=$3
-	echo -n "Checking for package ${pkgname} using ${customconfig}... "
+	printf "Checking for package ${pkgname} using ${customconfig}... "
 	if ${customconfig} --cflags > /dev/null 2>&1 ; then
 		echo "found"
 		echo "# configuration for package ${pkgname}" >> config.mk
