@@ -11,30 +11,14 @@
 # Change history
 #
 #  26.06.2009    erb    suppressed error messages due to unrepsonsive servers
+#  28.03.2010    erb    Added DB cache to speed things up (significantly!)
 #
-
-require 'net/http'
-require 'uri'
+$:.push(File.dirname($0))
+require 'feedgrabber'
 
 require 'rexml/document'
 include REXML
 
-require "open-uri"
-require 'timeout'
-
-#try to retrieve web site, following up to 5 redirects
-def geturl(url, depth=5)
-  raise ArgumentError, 'Followed more 4 redirections. Stopping this nightmare now.' if depth == 0
-  response = Net::HTTP.get_response(URI.parse(url))
-  case response
-    when Net::HTTPSuccess     then response.body
-    when Net::HTTPRedirection then geturl(response['location'], depth-1) # follow redirection
-  else
-    # any other error shall not make any noise (maybe shall we produce a fake RSS item)
-    ""
-  end
-end
-
 if ENV['http_proxy'].nil? && !ENV['HTTP_PROXY'].nil?
   ENV['http_proxy'] = ENV['HTTP_PROXY']
 end
@@ -107,66 +91,42 @@ end
 feedurl = FEEDS[feed]
 
 #get feed
-feed_text = ""
-retries=4
-begin
-  Timeout::timeout(15) do
-    f = open(feedurl)
-    feed_text = f.read unless f.nil?
-  end
-rescue Timeout::Error
-  retries -= 1
-  exit 1 if retries < 1
-  sleep 1
-  retry
-rescue
-  # any other error shall not make any noise (maybe shall we produce a fake RSS item)
-end
+fg = FeedGrabber.new("heisecache-#{feed}")
+feed_text = fg.getURL_uncached(feedurl)
 
-exit 2 if feed_text.length < 20
-
-#print "Got this feed: ", feed_text, "\n"; STDOUT.flush
+exit 2 unless feed_text && feed_text.length > 20
 
 xml = Document.new(feed_text)
 
 #loop over items
 xml.elements.each("//entry") do |item|
-
   # extract link to article
   article_url = item.elements['id'].text
   article_url.sub!(%r{from/.*$}, "")
   article_short_url = article_url.sub(%r{/[^/]*--/}, "/")
 
   # get full text for article
-  article_text = ""
-  retries = 4
+  article_text = fg.getURL(article_url)
+  next unless article_text && article_text.length > 20
+
+  # extract article comment link
   begin
-#    print "<!-- Reading article from ", article_url, " -->\n"; STDOUT.flush
-    Timeout::timeout(15) do
-      article = open(article_url)
-      article_text = article.read unless article.nil?
-    end
-  rescue Timeout::Error
-    retries -= 1
-    next if retries < 1
-    sleep 1
-    retry
+    comments = /<a href=\"(\/[a-z\/]*\/foren\/[^\/]*\/forum-[0-9]*\/list\/)\"/m.match(article_text)[1]
   rescue
+    comments =""
   end
-
-  next if article_text.length < 20
-
   article_text = shortenArticle(article_text)
+  
+  article_text += "<p><a href=\"http://www.heise.de#{comments}\">Kommentare</a></p>" if comments.length > 5 && comments.length < 150
 
   # insert full text article into feed
   description = Element.new("content")
+  description.add_attribute("type", "html")
   description.text= CData.new(article_text)
   item.add_element(description)
-
-  #guid = Element.new("guid")
-  #guid.text= article_short_url
-  #item.add_element(guid)
 end
+
+fg.cleanupDB
   
-#reproduce enriched feed
+# reproduce the content enriched feed
 xml.write($stdout, -1)
