@@ -4,6 +4,9 @@ use strict;
 use LWP::UserAgent;
 use URI::Escape;
 
+# $ARGV[0] is the URL of the article
+# $ARGV[1] is the title of the article
+
 # Daemonising the bookmarking process
 # Use this only is you are sure things 
 # are working as expected
@@ -15,7 +18,9 @@ if ($daemon){
         require Proc::Daemon;
         Proc::Damoen->import();
     };
-    unless ($@){
+    if($@){
+        warn();
+    }else{
         Proc::Daemon::Init();
     }
 }
@@ -31,8 +36,6 @@ my $ua = LWP::UserAgent->new(
     requests_redirectable => [],
 );
 
-# $ARGV[0] is the URL of the article
-# $ARGV[1] is the title of the article
 my $res = $ua->get($ARGV[0]);
 
 if ($res->status_line == 301){
@@ -41,13 +44,15 @@ if ($res->status_line == 301){
     $bkmrk_url = $ARGV[0];
 }
 
+my $safe_bkmrk_url = uri_escape($bkmrk_url);
 my $safe_desc=uri_escape($ARGV[1]);
-my $pinboard_url = $API_URL . "url=$bkmrk_url&tags=$tag&shared=no&toread=yes&description=$safe_desc&auth_token=$API_token";
+
+my $pinboard_url = $API_URL . "auth_token=$API_token&url=$safe_bkmrk_url&tags=$tag&shared=no&toread=yes&description=$safe_desc";
 my $content = `curl -s \"$pinboard_url\"`;
 
 if ($content =~ m!<result code="done" />!){
 #    print "Added to Pinboard\n";
 }else{
-    print "Something went wrong, not added. ";
-    print "See response: $content" if $content;
+    print " Opps $content" if $content;
+    print " Bookmark not added! URL: $pinboard_url";
 }
