@@ -4,7 +4,7 @@
 #include <sqlite3.h>
 #include <rss.h>
 #include <configcontainer.h>
-#include <mutex.h>
+#include <mutex>
 
 namespace newsbeuter {
 
@@ -15,15 +15,15 @@ class cache {
 	public:
 		cache(const std::string& cachefile, configcontainer * c);
 		~cache();
-		void externalize_rssfeed(std::tr1::shared_ptr<rss_feed> feed, bool reset_unread);
-		void internalize_rssfeed(std::tr1::shared_ptr<rss_feed> feed, rss_ignores * ign);
-		void update_rssitem_unread_and_enqueued(std::tr1::shared_ptr<rss_item> item, const std::string& feedurl);
+		void externalize_rssfeed(std::shared_ptr<rss_feed> feed, bool reset_unread);
+		std::shared_ptr<rss_feed> internalize_rssfeed(std::string rssurl, rss_ignores * ign);
+		void update_rssitem_unread_and_enqueued(std::shared_ptr<rss_item> item, const std::string& feedurl);
 		void update_rssitem_unread_and_enqueued(rss_item* item, const std::string& feedurl);
-		void cleanup_cache(std::vector<std::tr1::shared_ptr<rss_feed> >& feeds);
+		void cleanup_cache(std::vector<std::shared_ptr<rss_feed>>& feeds);
 		void do_vacuum();
-		std::vector<std::tr1::shared_ptr<rss_item> > search_for_items(const std::string& querystr, const std::string& feedurl);
+		std::vector<std::shared_ptr<rss_item>> search_for_items(const std::string& querystr, const std::string& feedurl);
 		void catchup_all(const std::string& feedurl = "");
-		void catchup_all(std::tr1::shared_ptr<rss_feed> feed);
+		void catchup_all(std::shared_ptr<rss_feed> feed);
 		void update_rssitem_flags(rss_item* item);
 		std::vector<std::string> get_feed_urls();
 		void fetch_lastmodified(const std::string& uri, time_t& t, std::string& etag);
@@ -40,15 +40,15 @@ class cache {
 	private:
 		void populate_tables();
 		void set_pragmas();
-		void delete_item(const std::tr1::shared_ptr<rss_item> item);
+		void delete_item(const std::shared_ptr<rss_item> item);
 		void clean_old_articles();
-		void update_rssitem_unlocked(std::tr1::shared_ptr<rss_item> item, const std::string& feedurl, bool reset_unread);
+		void update_rssitem_unlocked(std::shared_ptr<rss_item> item, const std::string& feedurl, bool reset_unread);
 
 		std::string prepare_query(const char * format, ...);
-			
+
 		sqlite3 * db;
 		configcontainer * cfg;
-		mutex mtx;
+		std::mutex mtx;
 };
 
 }
