@@ -12,7 +12,9 @@ class dialogs_formaction : public formaction {
 		virtual void prepare();
 		virtual void init();
 		virtual keymap_hint_entry * get_keymap_hint();
-		virtual std::string id() const { return "dialogs"; }
+		virtual std::string id() const {
+			return "dialogs";
+		}
 		virtual std::string title();
 		virtual void handle_cmdline(const std::string& cmd);
 
