@@ -9,7 +9,7 @@
 
 namespace newsbeuter {
 
-typedef std::pair<std::tr1::shared_ptr<rss_feed>, unsigned int> feedptr_pos_pair;
+typedef std::pair<std::shared_ptr<rss_feed>, unsigned int> feedptr_pos_pair;
 
 class feedlist_formaction : public formaction {
 	public:
@@ -17,18 +17,20 @@ class feedlist_formaction : public formaction {
 		virtual ~feedlist_formaction();
 		virtual void prepare();
 		virtual void init();
-		void set_feedlist(std::vector<std::tr1::shared_ptr<rss_feed> >& feeds);
-		void update_visible_feeds(std::vector<std::tr1::shared_ptr<rss_feed> >& feeds);
+		void set_feedlist(std::vector<std::shared_ptr<rss_feed>>& feeds);
+		void update_visible_feeds(std::vector<std::shared_ptr<rss_feed>>& feeds);
 		void set_tags(const std::vector<std::string>& t);
 		virtual keymap_hint_entry * get_keymap_hint();
-		std::tr1::shared_ptr<rss_feed> get_feed();
+		std::shared_ptr<rss_feed> get_feed();
 
-		virtual void set_redraw(bool b) { 
-			formaction::set_redraw(b); 
+		virtual void set_redraw(bool b) {
+			formaction::set_redraw(b);
 			apply_filter = !(v->get_cfg()->get_configvalue_as_bool("show-read-feeds"));
 		}
 
-		virtual std::string id() const { return "feedlist"; }
+		virtual std::string id() const {
+			return "feedlist";
+		}
 		virtual std::string title();
 
 		bool jump_to_next_unread_feed(unsigned int& feedpos);
@@ -61,13 +63,12 @@ class feedlist_formaction : public formaction {
 
 		void set_pos();
 
-		std::string get_title(std::tr1::shared_ptr<rss_feed> feed);
+		std::string get_title(std::shared_ptr<rss_feed> feed);
 
-		std::string format_line(const std::string& feedlist_format, std::tr1::shared_ptr<rss_feed> feed, unsigned int pos, unsigned int width);
+		std::string format_line(const std::string& feedlist_format, std::shared_ptr<rss_feed> feed, unsigned int pos, unsigned int width);
 
 		bool zero_feedpos;
 		unsigned int feeds_shown;
-		bool auto_open;
 		bool quit;
 		std::vector<feedptr_pos_pair> visible_feeds;
 		std::string tag;
@@ -78,7 +79,7 @@ class feedlist_formaction : public formaction {
 
 		history filterhistory;
 
-		std::tr1::shared_ptr<rss_feed> search_dummy_feed;
+		std::shared_ptr<rss_feed> search_dummy_feed;
 
 		unsigned int filterpos;
 		bool set_filterpos;
