@@ -13,10 +13,16 @@ class filebrowser_formaction : public formaction {
 		virtual void init();
 		virtual keymap_hint_entry * get_keymap_hint();
 
-		inline void set_dir(const std::string& d) { dir = d; }
-		inline void set_default_filename(const std::string& fn) { default_filename = fn; }
+		inline void set_dir(const std::string& d) {
+			dir = d;
+		}
+		inline void set_default_filename(const std::string& fn) {
+			default_filename = fn;
+		}
 
-		virtual std::string id() const { return "filebrowser"; }
+		virtual std::string id() const {
+			return "filebrowser";
+		}
 		virtual std::string title();
 
 	private:
