@@ -13,8 +13,12 @@ class filtercontainer : public config_action_handler {
 		virtual ~filtercontainer();
 		virtual void handle_action(const std::string& action, const std::vector<std::string>& params);
 		virtual void dump_config(std::vector<std::string>& config_output);
-		inline std::vector<filter_name_expr_pair>& get_filters() { return filters; }
-		inline unsigned int size() { return filters.size(); }
+		inline std::vector<filter_name_expr_pair>& get_filters() {
+			return filters;
+		}
+		inline unsigned int size() {
+			return filters.size();
+		}
 	private:
 		std::vector<filter_name_expr_pair> filters;
 
