@@ -12,7 +12,9 @@ class help_formaction : public formaction {
 		virtual void prepare();
 		virtual void init();
 		virtual keymap_hint_entry * get_keymap_hint();
-		virtual std::string id() const { return "help"; }
+		virtual std::string id() const {
+			return "help";
+		}
 		virtual std::string title();
 
 		virtual void finished_qna(operation op);
