@@ -2,12 +2,12 @@
 #define LOGGER__H
 
 #include <fstream>
-#include <mutex.h>
+#include <mutex>
 #include <config.h>
 
 namespace newsbeuter {
 
-	enum loglevel { LOG_NONE = 0, LOG_USERERROR, LOG_CRITICAL, LOG_ERROR, LOG_WARN, LOG_INFO, LOG_DEBUG };
+enum loglevel { LOG_NONE = 0, LOG_USERERROR, LOG_CRITICAL, LOG_ERROR, LOG_WARN, LOG_INFO, LOG_DEBUG };
 
 
 class logger {
@@ -22,12 +22,14 @@ class logger {
 	private:
 		logger();
 		logger(const logger &) {}
-		logger& operator=(const logger &) { return *this; }
+		logger& operator=(const logger &) {
+			return *this;
+		}
 		~logger() { }
 
 		loglevel curlevel;
-		mutex logMutex;
-		static mutex instanceMutex;
+		std::mutex logMutex;
+		static std::mutex instanceMutex;
 		std::fstream f;
 		std::fstream ef;
 };
