@@ -1,7 +1,7 @@
 #ifndef PODBEUTER_PODDLTHREAD__H
 #define PODBEUTER_PODDLTHREAD__H
 
-#include <thread.h>
+#include <thread>
 #include <download.h>
 #include <fstream>
 
@@ -12,19 +12,19 @@
 
 namespace podbeuter {
 
-class poddlthread : public newsbeuter::thread {
+class poddlthread {
 	public:
 		poddlthread(download * dl_, newsbeuter::configcontainer *);
 		virtual ~poddlthread();
 		size_t write_data(void * buffer, size_t size, size_t nmemb);
 		int progress(double dlnow, double dltotal);
+		void operator()();
 	protected:
-		virtual void run();
 		double compute_kbps();
 	private:
 		void mkdir_p(const char * file);
 		download * dl;
-		std::ofstream f;
+		std::ofstream *f;
 		timeval tv1;
 		timeval tv2;
 		size_t bytecount;
