@@ -7,7 +7,7 @@
 #include <regex.h>
 #include <matcher.h>
 #include <utility>
-#include <tr1/memory>
+#include <memory>
 
 namespace newsbeuter {
 
@@ -21,14 +21,18 @@ class regexmanager : public config_action_handler {
 		void remove_last_regex(const std::string& location);
 		int article_matches(matchable * item);
 	private:
-		typedef std::pair<std::vector<regex_t *>, std::vector<std::string> > rc_pair;
+		typedef std::pair<std::vector<regex_t *>, std::vector<std::string>> rc_pair;
 		std::map<std::string, rc_pair> locations;
 		std::vector<std::string> cheat_store_for_dump_config;
-		std::vector<std::pair<std::tr1::shared_ptr<matcher>, int> > matchers;
+		std::vector<std::pair<std::shared_ptr<matcher>, int>> matchers;
 		std::string extract_initial_marker(const std::string& str);
 	public:
-		inline std::vector<std::string>& get_attrs(const std::string& loc) { return locations[loc].second; }
-		inline std::vector<regex_t *>& get_regexes(const std::string& loc) { return locations[loc].first; }
+		inline std::vector<std::string>& get_attrs(const std::string& loc) {
+			return locations[loc].second;
+		}
+		inline std::vector<regex_t *>& get_regexes(const std::string& loc) {
+			return locations[loc].first;
+		}
 };
 
 }
