@@ -14,7 +14,7 @@ class ttrss_api : public remote_api {
 		virtual ~ttrss_api();
 		virtual bool authenticate();
 		virtual struct json_object * run_op(const std::string& op, const std::map<std::string, std::string>& args,
-						    bool try_login = true);
+		                                    bool try_login = true);
 		virtual std::vector<tagged_feedurl> get_subscribed_urls();
 		virtual void configure_handle(CURL * handle);
 		virtual bool mark_all_read(const std::string& feedurl);
@@ -32,18 +32,17 @@ class ttrss_api : public remote_api {
 		std::string auth_info;
 		const char * auth_info_ptr;
 		bool single;
-		mutex auth_lock;
+		std::mutex auth_lock;
 };
 
 class ttrss_urlreader : public urlreader {
 	public:
-		ttrss_urlreader(configcontainer * c, const std::string& url_file, remote_api * a);
+		ttrss_urlreader(const std::string& url_file, remote_api * a);
 		virtual ~ttrss_urlreader();
 		virtual void write_config();
 		virtual void reload();
 		virtual std::string get_source();
 	private:
-		configcontainer * cfg;
 		std::string file;
 		remote_api * api;
 };
