@@ -13,8 +13,12 @@ class urlview_formaction : public formaction {
 		virtual void prepare();
 		virtual void init();
 		virtual keymap_hint_entry * get_keymap_hint();
-		inline void set_links(const std::vector<linkpair>& l) { links = l; }
-		virtual std::string id() const { return "urlview"; }
+		inline void set_links(const std::vector<linkpair>& l) {
+			links = l;
+		}
+		virtual std::string id() const {
+			return "urlview";
+		}
 		virtual std::string title();
 		virtual void handle_cmdline(const std::string& cmd);
 	private:
