@@ -21,17 +21,17 @@ class curl_handle {
 		curl_handle &operator=(const curl_handle &);
 	public:
 		curl_handle()
-			: h(0)
-		{
+			: h(0) {
 			h = curl_easy_init();
 			if (!h)
 				throw std::runtime_error("Can't obtain curl handle");
 		}
-		~curl_handle()
-		{
+		~curl_handle() {
 			curl_easy_cleanup(h);
 		}
-		CURL *ptr() { return h; }
+		CURL *ptr() {
+			return h;
+		}
 };
 
 class utils {
@@ -77,14 +77,16 @@ class utils {
 		static size_t strwidth_stfl(const std::string& str);
 		static size_t wcswidth_stfl(const std::wstring& str, size_t size);
 
-		static inline unsigned int max(unsigned int a, unsigned int b) { return (a > b) ? a : b; }
+		static inline unsigned int max(unsigned int a, unsigned int b) {
+			return (a > b) ? a : b;
+		}
 
 		static unsigned int to_u(const std::string& str);
 
 		static bool is_valid_color(const std::string& color);
 		static bool is_valid_attribute(const std::string& attrib);
 
-		static std::vector<std::pair<unsigned int, unsigned int> > partition_indexes(unsigned int start, unsigned int end, unsigned int parts);
+		static std::vector<std::pair<unsigned int, unsigned int>> partition_indexes(unsigned int start, unsigned int end, unsigned int parts);
 
 		static std::string join(const std::vector<std::string>& strings, const std::string& separator);
 
