@@ -25,7 +25,7 @@ static size_t my_write_data(void *buffer, size_t size, size_t nmemb, void *userp
 
 namespace rsspp {
 
-parser::parser(unsigned int timeout, const char * user_agent, const char * proxy, const char * proxy_auth, curl_proxytype proxy_type) 
+parser::parser(unsigned int timeout, const char * user_agent, const char * proxy, const char * proxy_auth, curl_proxytype proxy_type)
 	: to(timeout), ua(user_agent), prx(proxy), prxauth(proxy_auth), prxtype(proxy_type), doc(0), lm(0) {
 }
 
@@ -39,8 +39,7 @@ struct header_values {
 	std::string etag;
 
 	header_values()
-		: lastmodified(0)
-	{
+		: lastmodified(0) {
 	}
 };
 
@@ -257,7 +256,7 @@ feed parser::parse_xmlnode(xmlNode* node) {
 				}
 			}
 
-			std::tr1::shared_ptr<rss_parser> parser = rss_parser_factory::get_object(f, doc);
+			std::shared_ptr<rss_parser> parser = rss_parser_factory::get_object(f, doc);
 
 			try {
 				parser->parse_feed(f, node);
