@@ -78,8 +78,12 @@ class parser {
 		feed parse_url(const std::string& url, time_t lastmodified = 0, const std::string& etag = "", newsbeuter::remote_api * api = 0, const std::string& cookie_cache = "", CURL *ehandle = 0);
 		feed parse_buffer(const char * buffer, size_t size, const char * url = NULL);
 		feed parse_file(const std::string& filename);
-		time_t get_last_modified() { return lm; }
-		const std::string& get_etag() { return et; }
+		time_t get_last_modified() {
+			return lm;
+		}
+		const std::string& get_etag() {
+			return et;
+		}
 
 		static void global_init();
 		static void global_cleanup();
