@@ -19,8 +19,12 @@ namespace newsbeuter {
 
 struct cb_handler {
 		cb_handler() : c(-1) { }
-		void set_count(int i) { c = i; }
-		int count() { return c; }
+		void set_count(int i) {
+			c = i;
+		}
+		int count() {
+			return c;
+		}
 	private:
 		int c;
 };
@@ -52,7 +56,7 @@ static int single_string_callback(void * handler, int argc, char ** argv, char *
 }
 
 static int rssfeed_callback(void * myfeed, int argc, char ** argv, char ** /* azColName */) {
-	std::tr1::shared_ptr<rss_feed>* feed = static_cast<std::tr1::shared_ptr<rss_feed>* >(myfeed);
+	std::shared_ptr<rss_feed>* feed = static_cast<std::shared_ptr<rss_feed>* >(myfeed);
 	// normaly, this shouldn't happen, but we keep the assert()s here nevertheless
 	assert(argc == 3);
 	assert(argv[0] != NULL);
@@ -94,19 +98,19 @@ static int vectorofstring_callback(void * vp, int argc, char ** argv, char ** /*
 }
 
 static int rssitem_callback(void * myfeed, int argc, char ** argv, char ** /* azColName */) {
-	std::tr1::shared_ptr<rss_feed>* feed = static_cast<std::tr1::shared_ptr<rss_feed>* >(myfeed);
+	std::shared_ptr<rss_feed>* feed = static_cast<std::shared_ptr<rss_feed>* >(myfeed);
 	assert (argc == 13);
-	std::tr1::shared_ptr<rss_item> item(new rss_item(NULL));
+	std::shared_ptr<rss_item> item(new rss_item(NULL));
 	item->set_guid(argv[0]);
 	item->set_title(argv[1]);
 	item->set_author(argv[2]);
 	item->set_link(argv[3]);
-	
+
 	std::istringstream is(argv[4]);
 	time_t t;
 	is >> t;
 	item->set_pubDate(t);
-	
+
 	item->set_size(utils::to_u(argv[5]));
 	item->set_unread((std::string("1") == argv[6]));
 
@@ -127,26 +131,26 @@ static int fill_content_callback(void * myfeed, int argc, char ** argv, char **
 	rss_feed * feed = static_cast<rss_feed *>(myfeed);
 	assert(argc == 2);
 	if (argv[0]) {
-		std::tr1::shared_ptr<rss_item> item = feed->get_item_by_guid_unlocked(argv[0]);
+		std::shared_ptr<rss_item> item = feed->get_item_by_guid_unlocked(argv[0]);
 		item->set_description(argv[1] ? argv[1] : "");
 	}
 	return 0;
 }
 
 static int search_item_callback(void * myfeed, int argc, char ** argv, char ** /* azColName */) {
-	std::vector<std::tr1::shared_ptr<rss_item> > * items = static_cast<std::vector<std::tr1::shared_ptr<rss_item> > *>(myfeed);
+	std::vector<std::shared_ptr<rss_item>> * items = static_cast<std::vector<std::shared_ptr<rss_item>> *>(myfeed);
 	assert (argc == 13);
-	std::tr1::shared_ptr<rss_item> item(new rss_item(NULL));
+	std::shared_ptr<rss_item> item(new rss_item(NULL));
 	item->set_guid(argv[0]);
 	item->set_title(argv[1]);
 	item->set_author(argv[2]);
 	item->set_link(argv[3]);
-	
+
 	std::istringstream is(argv[4]);
 	time_t t;
 	is >> t;
 	item->set_pubDate(t);
-	
+
 	item->set_size(utils::to_u(argv[5]));
 	item->set_unread((std::string("1") == argv[6]));
 	item->set_feedurl(argv[7]);
@@ -184,10 +188,10 @@ cache::~cache() {
 
 void cache::set_pragmas() {
 	int rc;
-	
+
 	// first, we need to swithc off synchronous writing as it's slow as hell
 	rc = sqlite3_exec(db, "PRAGMA synchronous = OFF;", NULL, NULL, NULL);
-	
+
 	if (rc != SQLITE_OK) {
 		LOG(LOG_CRITICAL,"setting PRAGMA synchronous = OFF failed");
 		throw dbexception(db);
@@ -207,29 +211,29 @@ void cache::populate_tables() {
 	int rc;
 
 	rc = sqlite3_exec(db,"CREATE TABLE rss_feed ( "
-						" rssurl VARCHAR(1024) PRIMARY KEY NOT NULL, "
-						" url VARCHAR(1024) NOT NULL, "
-						" title VARCHAR(1024) NOT NULL ); " , NULL, NULL, NULL);
+	                  " rssurl VARCHAR(1024) PRIMARY KEY NOT NULL, "
+	                  " url VARCHAR(1024) NOT NULL, "
+	                  " title VARCHAR(1024) NOT NULL ); " , NULL, NULL, NULL);
 
 	LOG(LOG_DEBUG, "cache::populate_tables: CREATE TABLE rss_feed rc = %d", rc);
 
 	rc = sqlite3_exec(db,"CREATE TABLE rss_item ( "
-						" id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL, "
-						" guid VARCHAR(64) NOT NULL, "
-						" title VARCHAR(1024) NOT NULL, "
-						" author VARCHAR(1024) NOT NULL, "
-						" url VARCHAR(1024) NOT NULL, "
-						" feedurl VARCHAR(1024) NOT NULL, "
-						" pubDate INTEGER NOT NULL, "
-						" content VARCHAR(65535) NOT NULL,"
-						" unread INTEGER(1) NOT NULL );", NULL, NULL, NULL);
+	                  " id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL, "
+	                  " guid VARCHAR(64) NOT NULL, "
+	                  " title VARCHAR(1024) NOT NULL, "
+	                  " author VARCHAR(1024) NOT NULL, "
+	                  " url VARCHAR(1024) NOT NULL, "
+	                  " feedurl VARCHAR(1024) NOT NULL, "
+	                  " pubDate INTEGER NOT NULL, "
+	                  " content VARCHAR(65535) NOT NULL,"
+	                  " unread INTEGER(1) NOT NULL );", NULL, NULL, NULL);
 	LOG(LOG_DEBUG, "cache::populate_tables: CREATE TABLE rss_item rc = %d", rc);
 
 	rc = sqlite3_exec(db, "CREATE TABLE google_replay ( "
-						" id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL, "
-						" guid VARCHAR(64) NOT NULL, "
-						" state INTEGER NOT NULL, "
-						" ts INTEGER NOT NULL );", NULL, NULL, NULL);
+	                  " id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL, "
+	                  " guid VARCHAR(64) NOT NULL, "
+	                  " state INTEGER NOT NULL, "
+	                  " ts INTEGER NOT NULL );", NULL, NULL, NULL);
 	LOG(LOG_DEBUG, "cache::populate_tables: CREATE TABLE google_replay rc = %d", rc);
 
 	/* we need to do these ALTER TABLE statements because we need to store additional data for the podcast support */
@@ -254,7 +258,7 @@ void cache::populate_tables() {
 
 	rc = sqlite3_exec(db, "CREATE INDEX IF NOT EXISTS idx_feedurl ON rss_item(feedurl);", NULL, NULL, NULL);
 	LOG(LOG_DEBUG, "cache::populate_tables: CREATE INDEX ON rss_item(feedurl) (5) rc = %d", rc);
-	if(rc == SQLITE_OK){
+	if(rc == SQLITE_OK) {
 		/* we analyse the indices for better statistics */
 		rc = sqlite3_exec(db, "ANALYZE;", NULL, NULL, NULL);
 		LOG(LOG_DEBUG, "cache::populate_tables: ANALYZE indices (6) rc = %d", rc);
@@ -284,7 +288,7 @@ void cache::populate_tables() {
 
 
 void cache::fetch_lastmodified(const std::string& feedurl, time_t& t, std::string& etag) {
-	scope_mutex lock(&mtx);
+	std::lock_guard<std::mutex> lock(mtx);
 	std::string query = prepare_query("SELECT lastmodified, etag FROM rss_feed WHERE rssurl = '%q';", feedurl.c_str());
 	LOG(LOG_DEBUG, "running: query: %s", query.c_str());
 	header_values result = { 0, "" };
@@ -303,7 +307,7 @@ void cache::update_lastmodified(const std::string& feedurl, time_t t, const std:
 		LOG(LOG_INFO, "cache::update_lastmodified: both time and etag are empty, not updating anything");
 		return;
 	}
-	scope_mutex lock(&mtx);
+	std::lock_guard<std::mutex> lock(mtx);
 	std::string query = "UPDATE rss_feed SET ";
 	if (t > 0)
 		query.append(utils::strprintf("lastmodified = '%d'", t));
@@ -316,7 +320,7 @@ void cache::update_lastmodified(const std::string& feedurl, time_t t, const std:
 }
 
 void cache::mark_item_deleted(const std::string& guid, bool b) {
-	scope_mutex lock(&mtx);
+	std::lock_guard<std::mutex> lock(mtx);
 	std::string query = prepare_query("UPDATE rss_item SET deleted = %u WHERE guid = '%q'", b ? 1 : 0, guid.c_str());
 	int rc = sqlite3_exec(db, query.c_str(), NULL, NULL, NULL);
 	LOG(LOG_DEBUG, "cache::mark_item_deleted ran SQL statement: %s result = %d", query.c_str(), rc);
@@ -324,7 +328,7 @@ void cache::mark_item_deleted(const std::string& guid, bool b) {
 
 
 std::vector<std::string> cache::get_feed_urls() {
-	scope_mutex lock(&mtx);
+	std::lock_guard<std::mutex> lock(mtx);
 	std::string query = "SELECT rssurl FROM rss_feed;";
 
 	std::vector<std::string> urls;
@@ -337,13 +341,13 @@ std::vector<std::string> cache::get_feed_urls() {
 
 
 // this function writes an rss_feed including all rss_items to the database
-void cache::externalize_rssfeed(std::tr1::shared_ptr<rss_feed> feed, bool reset_unread) {
+void cache::externalize_rssfeed(std::shared_ptr<rss_feed> feed, bool reset_unread) {
 	scope_measure m1("cache::externalize_feed");
 	if (feed->rssurl().substr(0,6) == "query:")
 		return;
 
-	scope_mutex lock(&mtx);
-	scope_mutex feedlock(&feed->item_mutex);
+	std::lock_guard<std::mutex> lock(mtx);
+	std::lock_guard<std::mutex> feedlock(feed->item_mutex);
 	//scope_transaction dbtrans(db);
 
 	cb_handler count_cbh;
@@ -357,24 +361,32 @@ void cache::externalize_rssfeed(std::tr1::shared_ptr<rss_feed> feed, bool reset_
 	LOG(LOG_DEBUG, "cache::externalize_rss_feed: rss_feeds with rssurl = '%s': found %d",feed->rssurl().c_str(), count);
 	if (count > 0) {
 		std::string updatequery = prepare_query("UPDATE rss_feed SET title = '%q', url = '%q', is_rtl = %u WHERE rssurl = '%q';",
-			feed->title_raw().c_str(),feed->link().c_str(), feed->is_rtl() ? 1 : 0, feed->rssurl().c_str());
+		                                        feed->title_raw().c_str(),feed->link().c_str(), feed->is_rtl() ? 1 : 0, feed->rssurl().c_str());
 		rc = sqlite3_exec(db,updatequery.c_str(),NULL,NULL,NULL);
+		if (rc != SQLITE_OK) {
+			LOG(LOG_CRITICAL,"query \"%s\" failed: error = %d", updatequery.c_str(), rc);
+			throw dbexception(db);
+		}
 		LOG(LOG_DEBUG,"ran SQL statement: %s", updatequery.c_str());
 	} else {
-		std::string insertquery = prepare_query("INSERT INTO rss_feed (rssurl, url, title, is_rtl) VALUES ( '%q', '%q', '%q', %u );", 
-			feed->rssurl().c_str(), feed->link().c_str(), feed->title_raw().c_str(), feed->is_rtl() ? 1 : 0);
+		std::string insertquery = prepare_query("INSERT INTO rss_feed (rssurl, url, title, is_rtl) VALUES ( '%q', '%q', '%q', %u );",
+		                                        feed->rssurl().c_str(), feed->link().c_str(), feed->title_raw().c_str(), feed->is_rtl() ? 1 : 0);
 		rc = sqlite3_exec(db,insertquery.c_str(),NULL,NULL,NULL);
+		if (rc != SQLITE_OK) {
+			LOG(LOG_CRITICAL,"query \"%s\" failed: error = %d", insertquery.c_str(), rc);
+			throw dbexception(db);
+		}
 		LOG(LOG_DEBUG,"ran SQL statement: %s", insertquery.c_str());
 	}
-	
+
 	unsigned int max_items = cfg->get_configvalue_as_int("max-items");
 
 	LOG(LOG_INFO, "cache::externalize_feed: max_items = %u feed.items().size() = %u", max_items, feed->total_item_count());
-	
+
 	if (max_items > 0 && feed->items().size() > max_items) {
-		std::vector<std::tr1::shared_ptr<rss_item> >::iterator it=feed->items().begin();
-		for (unsigned int i=0;i<max_items;++i)
-			++it;	
+		auto it=feed->items().begin();
+		for (unsigned int i=0; i<max_items; ++i)
+			++it;
 		if (it != feed->items().end())
 			feed->erase_items(it, feed->items().end()); // delete entries that are too much
 	}
@@ -383,7 +395,7 @@ void cache::externalize_rssfeed(std::tr1::shared_ptr<rss_feed> feed, bool reset_
 	time_t old_time = time(NULL) - days * 24*60*60;
 
 	// the reverse iterator is there for the sorting foo below (think about it)
-	for (std::vector<std::tr1::shared_ptr<rss_item> >::reverse_iterator it=feed->items().rbegin(); it != feed->items().rend(); ++it) {
+	for (auto it=feed->items().rbegin(); it != feed->items().rend(); ++it) {
 		if (days == 0 || (*it)->pubDate_timestamp() >= old_time)
 			update_rssitem_unlocked(*it, feed->rssurl(), reset_unread);
 	}
@@ -391,16 +403,20 @@ void cache::externalize_rssfeed(std::tr1::shared_ptr<rss_feed> feed, bool reset_
 
 // this function reads an rss_feed including all of its rss_items.
 // the feed parameter needs to have the rssurl member set.
-void cache::internalize_rssfeed(std::tr1::shared_ptr<rss_feed> feed, rss_ignores * ign) {
+std::shared_ptr<rss_feed> cache::internalize_rssfeed(std::string rssurl, rss_ignores * ign) {
 	scope_measure m1("cache::internalize_rssfeed");
-	if (feed->rssurl().substr(0,6) == "query:")
-		return;
 
-	scope_mutex lock(&mtx);
-	scope_mutex feedlock(&feed->item_mutex);
+	std::shared_ptr<rss_feed> feed(new rss_feed(this));
+	feed->set_rssurl(rssurl);
+
+	if (rssurl.substr(0,6) == "query:")
+		return feed;
+
+	std::lock_guard<std::mutex> lock(mtx);
+	std::lock_guard<std::mutex> feedlock(feed->item_mutex);
 
 	/* first, we check whether the feed is there at all */
-	std::string query = prepare_query("SELECT count(*) FROM rss_feed WHERE rssurl = '%q';",feed->rssurl().c_str());
+	std::string query = prepare_query("SELECT count(*) FROM rss_feed WHERE rssurl = '%q';",rssurl.c_str());
 	cb_handler count_cbh;
 	LOG(LOG_DEBUG,"running query: %s",query.c_str());
 	int rc = sqlite3_exec(db,query.c_str(),count_callback,&count_cbh,NULL);
@@ -410,11 +426,11 @@ void cache::internalize_rssfeed(std::tr1::shared_ptr<rss_feed> feed, rss_ignores
 	}
 
 	if (count_cbh.count() == 0) {
-		return;
+		return feed;
 	}
 
 	/* then we first read the feed from the database */
-	query = prepare_query("SELECT title, url, is_rtl FROM rss_feed WHERE rssurl = '%q';",feed->rssurl().c_str());
+	query = prepare_query("SELECT title, url, is_rtl FROM rss_feed WHERE rssurl = '%q';",rssurl.c_str());
 	LOG(LOG_DEBUG,"running query: %s",query.c_str());
 	rc = sqlite3_exec(db,query.c_str(),rssfeed_callback,&feed,NULL);
 	if (rc != SQLITE_OK) {
@@ -422,10 +438,8 @@ void cache::internalize_rssfeed(std::tr1::shared_ptr<rss_feed> feed, rss_ignores
 		throw dbexception(db);
 	}
 
-	feed->clear_items();
-
 	/* ...and then the associated items */
-	query = prepare_query("SELECT guid,title,author,url,pubDate,length(content),unread,feedurl,enclosure_url,enclosure_type,enqueued,flags,base FROM rss_item WHERE feedurl = '%q' AND deleted = 0 ORDER BY pubDate DESC, id DESC;",feed->rssurl().c_str());
+	query = prepare_query("SELECT guid,title,author,url,pubDate,length(content),unread,feedurl,enclosure_url,enclosure_type,enqueued,flags,base FROM rss_item WHERE feedurl = '%q' AND deleted = 0 ORDER BY pubDate DESC, id DESC;", rssurl.c_str());
 	LOG(LOG_DEBUG,"running query: %s",query.c_str());
 	rc = sqlite3_exec(db,query.c_str(),rssitem_callback,&feed,NULL);
 	if (rc != SQLITE_OK) {
@@ -434,57 +448,61 @@ void cache::internalize_rssfeed(std::tr1::shared_ptr<rss_feed> feed, rss_ignores
 	}
 
 	unsigned int i=0;
-	for (std::vector<std::tr1::shared_ptr<rss_item> >::iterator it=feed->items().begin(); it != feed->items().end(); ++it,++i) {
+	for (auto it=feed->items().begin(); it != feed->items().end(); ++it,++i) {
 		(*it)->set_cache(this);
 		(*it)->set_feedptr(feed);
 		(*it)->set_feedurl(feed->rssurl());
 
-		if (ign && ign->matches(it->get())) {
-			feed->erase_item(it);
-			// since we modified the vector, we need to reset the iterator
-			// to the beginning of the vector, and then fast-forward to
-			// the next element.
-			it = feed->items().begin();
-      --i;
-			for (int j=0;j<int(i);j++) {
-				++it;
+		try {
+			if (ign && ign->matches(it->get())) {
+				feed->erase_item(it);
+				// since we modified the vector, we need to reset the iterator
+				// to the beginning of the vector, and then fast-forward to
+				// the next element.
+				it = feed->items().begin();
+				--i;
+				for (int j=0; j<int(i); j++) {
+					++it;
+				}
+				continue;
 			}
-			continue;
+		} catch(const matcherexception& ex) {
+			LOG(LOG_DEBUG, "oops, matcher exception: %s", ex.what());
 		}
 	}
-	
+
 	unsigned int max_items = cfg->get_configvalue_as_int("max-items");
-	
+
 	if (max_items > 0 && feed->items().size() > max_items) {
-		std::vector<std::tr1::shared_ptr<rss_item> > flagged_items;
-		std::vector<std::tr1::shared_ptr<rss_item> >::iterator it=feed->items().begin();
-		for (unsigned int i=0;i<max_items;++i)
+		std::vector<std::shared_ptr<rss_item>> flagged_items;
+		auto it=feed->items().begin();
+		for (unsigned int j=0; j<max_items; ++j)
 			++it;
-		for (unsigned int i=max_items;i<feed->items().size();++i) {
-			if (feed->items()[i]->flags().length() == 0) {
-				delete_item(feed->items()[i]);
+		for (unsigned int j=max_items; j<feed->items().size(); ++j) {
+			if (feed->items()[j]->flags().length() == 0) {
+				delete_item(feed->items()[j]);
 			} else {
-				flagged_items.push_back(feed->items()[i]);
+				flagged_items.push_back(feed->items()[j]);
 			}
-		}	
+		}
 		feed->erase_items(it, feed->items().end()); // delete old entries
 		if (flagged_items.size() > 0) {
 			// if some flagged articles were saved, append them
-			for (std::vector<std::tr1::shared_ptr<rss_item> >::iterator jt=flagged_items.begin();jt!=flagged_items.end();++jt) {
-				feed->add_item(*jt);
+			for (auto item : flagged_items) {
+				feed->add_item(item);
 			}
 		}
 	}
 	feed->sort_unlocked(cfg->get_configvalue("article-sort-order"));
-
+	return feed;
 }
 
-std::vector<std::tr1::shared_ptr<rss_item> > cache::search_for_items(const std::string& querystr, const std::string& feedurl) {
+std::vector<std::shared_ptr<rss_item>> cache::search_for_items(const std::string& querystr, const std::string& feedurl) {
 	std::string query;
-	std::vector<std::tr1::shared_ptr<rss_item> > items;
+	std::vector<std::shared_ptr<rss_item>> items;
 	int rc;
 
-	scope_mutex lock(&mtx);
+	std::lock_guard<std::mutex> lock(mtx);
 	if (feedurl.length() > 0) {
 		query = prepare_query("SELECT guid,title,author,url,pubDate,length(content),unread,feedurl,enclosure_url,enclosure_type,enqueued,flags,base FROM rss_item WHERE (title LIKE '%%%q%%' OR content LIKE '%%%q%%') AND feedurl = '%q' AND deleted = 0 ORDER BY pubDate DESC, id DESC;",querystr.c_str(), querystr.c_str(), feedurl.c_str());
 	} else {
@@ -502,7 +520,7 @@ std::vector<std::tr1::shared_ptr<rss_item> > cache::search_for_items(const std::
 	return items;
 }
 
-void cache::delete_item(const std::tr1::shared_ptr<rss_item> item) {
+void cache::delete_item(const std::shared_ptr<rss_item> item) {
 	std::string query = prepare_query("DELETE FROM rss_item WHERE guid = '%q';",item->guid().c_str());
 	LOG(LOG_DEBUG,"running query: %s",query.c_str());
 	int rc = sqlite3_exec(db,query.c_str(),NULL,NULL,NULL);
@@ -513,7 +531,7 @@ void cache::delete_item(const std::tr1::shared_ptr<rss_item> item) {
 }
 
 void cache::do_vacuum() {
-	scope_mutex lock(&mtx);
+	std::lock_guard<std::mutex> lock(mtx);
 	const char * vacuum_query = "VACUUM;";
 	int rc = sqlite3_exec(db,vacuum_query,NULL,NULL,NULL);
 	if (rc != SQLITE_OK) {
@@ -521,8 +539,8 @@ void cache::do_vacuum() {
 	}
 }
 
-void cache::cleanup_cache(std::vector<std::tr1::shared_ptr<rss_feed> >& feeds) {
-	mtx.lock(); // we don't use the scope_mutex here... see comments below
+void cache::cleanup_cache(std::vector<std::shared_ptr<rss_feed>>& feeds) {
+	mtx.lock(); // we don't use the std::lock_guard<> here... see comments below
 
 	/*
 	 * cache cleanup means that all entries in both the rss_feed and rss_item tables that are associated with
@@ -540,14 +558,14 @@ void cache::cleanup_cache(std::vector<std::tr1::shared_ptr<rss_feed> >& feeds) {
 		unsigned int i = 0;
 		unsigned int feed_size = feeds.size();
 
-		for (std::vector<std::tr1::shared_ptr<rss_feed> >::iterator it=feeds.begin();it!=feeds.end();++it,++i) {
-			std::string name = prepare_query("'%q'",(*it)->rssurl().c_str());
+		for (auto feed : feeds) {
+			std::string name = prepare_query("'%q'",feed->rssurl().c_str());
 			list.append(name);
 			if (i < feed_size-1) {
 				list.append(", ");
 			}
 		}
-		list.append(")");
+		list.append("'')");
 
 		std::string cleanup_rss_feeds_statement("DELETE FROM rss_feed WHERE rssurl NOT IN ");
 		cleanup_rss_feeds_statement.append(list);
@@ -592,7 +610,7 @@ void cache::cleanup_cache(std::vector<std::tr1::shared_ptr<rss_feed> >& feeds) {
 	}
 }
 
-void cache::update_rssitem_unlocked(std::tr1::shared_ptr<rss_item> item, const std::string& feedurl, bool reset_unread) {
+void cache::update_rssitem_unlocked(std::shared_ptr<rss_item> item, const std::string& feedurl, bool reset_unread) {
 	std::string query = prepare_query("SELECT count(*) FROM rss_item WHERE guid = '%q';",item->guid().c_str());
 	cb_handler count_cbh;
 	LOG(LOG_DEBUG,"running query: %s", query.c_str());
@@ -623,17 +641,17 @@ void cache::update_rssitem_unlocked(std::tr1::shared_ptr<rss_item> item, const s
 		std::string update;
 		if (item->override_unread()) {
 			update = prepare_query("UPDATE rss_item SET title = '%q', author = '%q', url = '%q', feedurl = '%q', content = '%q', enclosure_url = '%q', enclosure_type = '%q', base = '%q', unread = '%d' WHERE guid = '%q'",
-				item->title_raw().c_str(), item->author_raw().c_str(), item->link().c_str(), 
-				feedurl.c_str(), item->description_raw().c_str(), 
-				item->enclosure_url().c_str(), item->enclosure_type().c_str(), item->get_base().c_str(),
-				(item->unread() ? 1 : 0),
-				item->guid().c_str());
+			                       item->title_raw().c_str(), item->author_raw().c_str(), item->link().c_str(),
+			                       feedurl.c_str(), item->description_raw().c_str(),
+			                       item->enclosure_url().c_str(), item->enclosure_type().c_str(), item->get_base().c_str(),
+			                       (item->unread() ? 1 : 0),
+			                       item->guid().c_str());
 		} else {
 			update = prepare_query("UPDATE rss_item SET title = '%q', author = '%q', url = '%q', feedurl = '%q', content = '%q', enclosure_url = '%q', enclosure_type = '%q', base = '%q' WHERE guid = '%q'",
-				item->title_raw().c_str(), item->author_raw().c_str(), item->link().c_str(), 
-				feedurl.c_str(), item->description_raw().c_str(), 
-				item->enclosure_url().c_str(), item->enclosure_type().c_str(), item->get_base().c_str(),
-				item->guid().c_str());
+			                       item->title_raw().c_str(), item->author_raw().c_str(), item->link().c_str(),
+			                       feedurl.c_str(), item->description_raw().c_str(),
+			                       item->enclosure_url().c_str(), item->enclosure_type().c_str(), item->get_base().c_str(),
+			                       item->guid().c_str());
 		}
 		LOG(LOG_DEBUG,"running query: %s", update.c_str());
 		rc = sqlite3_exec(db,update.c_str(),NULL,NULL,NULL);
@@ -643,10 +661,10 @@ void cache::update_rssitem_unlocked(std::tr1::shared_ptr<rss_item> item, const s
 		}
 	} else {
 		std::string insert = prepare_query("INSERT INTO rss_item (guid,title,author,url,feedurl,pubDate,content,unread,enclosure_url,enclosure_type,enqueued, base) "
-								"VALUES ('%q','%q','%q','%q','%q','%u','%q','%d','%q','%q',%d, '%q')",
-								item->guid().c_str(), item->title_raw().c_str(), item->author_raw().c_str(), 
-								item->link().c_str(), feedurl.c_str(), item->pubDate_timestamp(), item->description_raw().c_str(), (item->unread() ? 1 : 0),
-								item->enclosure_url().c_str(), item->enclosure_type().c_str(), item->enqueued() ? 1 : 0, item->get_base().c_str());
+		                                   "VALUES ('%q','%q','%q','%q','%q','%u','%q','%d','%q','%q',%d, '%q')",
+		                                   item->guid().c_str(), item->title_raw().c_str(), item->author_raw().c_str(),
+		                                   item->link().c_str(), feedurl.c_str(), item->pubDate_timestamp(), item->description_raw().c_str(), (item->unread() ? 1 : 0),
+		                                   item->enclosure_url().c_str(), item->enclosure_type().c_str(), item->enqueued() ? 1 : 0, item->get_base().c_str());
 		LOG(LOG_DEBUG,"running query: %s", insert.c_str());
 		rc = sqlite3_exec(db,insert.c_str(),NULL,NULL,NULL);
 		if (rc != SQLITE_OK) {
@@ -656,13 +674,13 @@ void cache::update_rssitem_unlocked(std::tr1::shared_ptr<rss_item> item, const s
 	}
 }
 
-void cache::catchup_all(std::tr1::shared_ptr<rss_feed> feed) {
-	scope_mutex lock(&mtx);
-	scope_mutex feedlock(&feed->item_mutex);
+void cache::catchup_all(std::shared_ptr<rss_feed> feed) {
+	std::lock_guard<std::mutex> lock(mtx);
+	std::lock_guard<std::mutex> itemlock(feed->item_mutex);
 	std::string query = "UPDATE rss_item SET unread = '0' WHERE unread != '0' AND guid IN (";
 
-	for (std::vector<std::tr1::shared_ptr<rss_item> >::iterator it=feed->items().begin();it!=feed->items().end();++it) {
-		query.append(prepare_query("'%q',", (*it)->guid().c_str()));
+	for (auto item : feed->items()) {
+		query.append(prepare_query("'%q',", item->guid().c_str()));
 	}
 	query.append("'');");
 
@@ -676,7 +694,7 @@ void cache::catchup_all(std::tr1::shared_ptr<rss_feed> feed) {
 
 /* this function marks all rss_items (optionally of a certain feed url) as read */
 void cache::catchup_all(const std::string& feedurl) {
-	scope_mutex lock(&mtx);
+	std::lock_guard<std::mutex> lock(mtx);
 
 	std::string query;
 	if (feedurl.length() > 0) {
@@ -693,7 +711,7 @@ void cache::catchup_all(const std::string& feedurl) {
 }
 
 void cache::update_rssitem_unread_and_enqueued(rss_item* item, const std::string& feedurl) {
-	scope_mutex lock(&mtx);
+	std::lock_guard<std::mutex> lock(mtx);
 
 	std::string query = prepare_query("SELECT count(*) FROM rss_item WHERE guid = '%q';",item->guid().c_str());
 	cb_handler count_cbh;
@@ -706,7 +724,7 @@ void cache::update_rssitem_unread_and_enqueued(rss_item* item, const std::string
 
 	if (count_cbh.count() > 0) {
 		std::string update = prepare_query("UPDATE rss_item SET unread = '%d', enqueued = '%d' WHERE guid = '%q'",
-			item->unread()?1:0, item->enqueued()?1:0, item->guid().c_str());
+		                                   item->unread()?1:0, item->enqueued()?1:0, item->guid().c_str());
 		LOG(LOG_DEBUG,"running query: %s", update.c_str());
 		rc = sqlite3_exec(db,update.c_str(),NULL,NULL,NULL);
 		if (rc != SQLITE_OK) {
@@ -715,11 +733,11 @@ void cache::update_rssitem_unread_and_enqueued(rss_item* item, const std::string
 		}
 	} else {
 		std::string insert = prepare_query("INSERT INTO rss_item (guid,title,author,url,feedurl,pubDate,content,unread,enclosure_url,enclosure_type,enqueued,flags,base) "
-										"VALUES ('%q','%q','%q','%q','%q','%u','%q','%d','%q','%q',%d, '%q', '%q')",
-										item->guid().c_str(), item->title_raw().c_str(), item->author_raw().c_str(), 
-										item->link().c_str(), feedurl.c_str(), item->pubDate_timestamp(), item->description_raw().c_str(), item->unread() ? 1 : 0,
-										item->enclosure_url().c_str(), item->enclosure_type().c_str(), item->enqueued() ? 1 : 0, item->flags().c_str(), 
-										item->get_base().c_str());
+		                                   "VALUES ('%q','%q','%q','%q','%q','%u','%q','%d','%q','%q',%d, '%q', '%q')",
+		                                   item->guid().c_str(), item->title_raw().c_str(), item->author_raw().c_str(),
+		                                   item->link().c_str(), feedurl.c_str(), item->pubDate_timestamp(), item->description_raw().c_str(), item->unread() ? 1 : 0,
+		                                   item->enclosure_url().c_str(), item->enclosure_type().c_str(), item->enqueued() ? 1 : 0, item->flags().c_str(),
+		                                   item->get_base().c_str());
 		LOG(LOG_DEBUG,"running query: %s", insert.c_str());
 		rc = sqlite3_exec(db,insert.c_str(),NULL,NULL,NULL);
 		if (rc != SQLITE_OK) {
@@ -730,8 +748,8 @@ void cache::update_rssitem_unread_and_enqueued(rss_item* item, const std::string
 }
 
 /* this function updates the unread and enqueued flags */
-void cache::update_rssitem_unread_and_enqueued(std::tr1::shared_ptr<rss_item> item, const std::string& feedurl) {
-	scope_mutex lock(&mtx);
+void cache::update_rssitem_unread_and_enqueued(std::shared_ptr<rss_item> item, const std::string& feedurl) {
+	std::lock_guard<std::mutex> lock(mtx);
 
 	std::string query = prepare_query("SELECT count(*) FROM rss_item WHERE guid = '%q';",item->guid().c_str());
 	cb_handler count_cbh;
@@ -744,7 +762,7 @@ void cache::update_rssitem_unread_and_enqueued(std::tr1::shared_ptr<rss_item> it
 
 	if (count_cbh.count() > 0) {
 		std::string update = prepare_query("UPDATE rss_item SET unread = '%d', enqueued = '%d' WHERE guid = '%q'",
-			item->unread()?1:0, item->enqueued()?1:0, item->guid().c_str());
+		                                   item->unread()?1:0, item->enqueued()?1:0, item->guid().c_str());
 		LOG(LOG_DEBUG,"running query: %s", update.c_str());
 		rc = sqlite3_exec(db,update.c_str(),NULL,NULL,NULL);
 		if (rc != SQLITE_OK) {
@@ -753,11 +771,11 @@ void cache::update_rssitem_unread_and_enqueued(std::tr1::shared_ptr<rss_item> it
 		}
 	} else {
 		std::string insert = prepare_query("INSERT INTO rss_item (guid,title,author,url,feedurl,pubDate,content,unread,enclosure_url,enclosure_type,enqueued,flags,base) "
-										"VALUES ('%q','%q','%q','%q','%q','%u','%q','%d','%q','%q',%d, '%q', '%q')",
-										item->guid().c_str(), item->title_raw().c_str(), item->author_raw().c_str(), 
-										item->link().c_str(), feedurl.c_str(), item->pubDate_timestamp(), item->description_raw().c_str(), (item->unread() ? 1 : 0),
-										item->enclosure_url().c_str(), item->enclosure_type().c_str(), item->enqueued() ? 1 : 0, item->flags().c_str(),
-										item->get_base().c_str());
+		                                   "VALUES ('%q','%q','%q','%q','%q','%u','%q','%d','%q','%q',%d, '%q', '%q')",
+		                                   item->guid().c_str(), item->title_raw().c_str(), item->author_raw().c_str(),
+		                                   item->link().c_str(), feedurl.c_str(), item->pubDate_timestamp(), item->description_raw().c_str(), (item->unread() ? 1 : 0),
+		                                   item->enclosure_url().c_str(), item->enclosure_type().c_str(), item->enqueued() ? 1 : 0, item->flags().c_str(),
+		                                   item->get_base().c_str());
 		LOG(LOG_DEBUG,"running query: %s", insert.c_str());
 		rc = sqlite3_exec(db,insert.c_str(),NULL,NULL,NULL);
 		if (rc != SQLITE_OK) {
@@ -782,7 +800,7 @@ std::string cache::prepare_query(const char * format, ...) {
 }
 
 void cache::update_rssitem_flags(rss_item* item) {
-	scope_mutex lock(&mtx);
+	std::lock_guard<std::mutex> lock(mtx);
 
 	std::string update = prepare_query("UPDATE rss_item SET flags = '%q' WHERE guid = '%q';", item->flags().c_str(), item->guid().c_str());
 	LOG(LOG_DEBUG,"running query: %s", update.c_str());
@@ -800,12 +818,12 @@ void cache::remove_old_deleted_items(const std::string& rssurl, const std::vecto
 		return;
 	}
 	std::string guidset = "(";
-	for (std::vector<std::string>::const_iterator it=guids.begin();it!=guids.end();++it) {
-		guidset.append(prepare_query("'%q', ", it->c_str()));
+	for (auto guid : guids) {
+		guidset.append(prepare_query("'%q', ", guid.c_str()));
 	}
 	guidset.append("'')");
 	std::string query = prepare_query("DELETE FROM rss_item WHERE feedurl = '%q' AND deleted = 1 AND guid NOT IN %s;", rssurl.c_str(), guidset.c_str());
-	scope_mutex lock(&mtx);
+	std::lock_guard<std::mutex> lock(mtx);
 	int rc = sqlite3_exec(db, query.c_str(), NULL, NULL, NULL);
 	if (rc != SQLITE_OK) {
 		LOG(LOG_CRITICAL, "query \"%s\" failed: error = %d", query.c_str(), rc);
@@ -816,7 +834,7 @@ void cache::remove_old_deleted_items(const std::string& rssurl, const std::vecto
 }
 
 unsigned int cache::get_unread_count() {
-	scope_mutex lock(&mtx);
+	std::lock_guard<std::mutex> lock(mtx);
 
 	std::string countquery = "SELECT count(id) FROM rss_item WHERE unread = 1;";
 	cb_handler count_cbh;
@@ -829,8 +847,8 @@ unsigned int cache::get_unread_count() {
 void cache::mark_items_read_by_guid(const std::vector<std::string>& guids) {
 	scope_measure m1("cache::mark_items_read_by_guid");
 	std::string guidset("(");
-	for (std::vector<std::string>::const_iterator it=guids.begin();it!=guids.end();++it) {
-		guidset.append(prepare_query("'%q', ", it->c_str()));
+	for (auto guid : guids) {
+		guidset.append(prepare_query("'%q', ", guid.c_str()));
 	}
 	guidset.append("'')");
 
@@ -838,7 +856,7 @@ void cache::mark_items_read_by_guid(const std::vector<std::string>& guids) {
 
 	int rc;
 	{
-		scope_mutex lock(&mtx);
+		std::lock_guard<std::mutex> lock(mtx);
 		rc = sqlite3_exec(db, updatequery.c_str(), NULL, NULL, NULL);
 	}
 
@@ -856,7 +874,7 @@ std::vector<std::string> cache::get_read_item_guids() {
 
 	int rc;
 	{
-		scope_mutex lock(&mtx);
+		std::lock_guard<std::mutex> lock(mtx);
 		rc = sqlite3_exec(db, query.c_str(), vectorofstring_callback, &guids, NULL);
 	}
 
@@ -870,7 +888,7 @@ std::vector<std::string> cache::get_read_item_guids() {
 }
 
 void cache::clean_old_articles() {
-	scope_mutex lock(&mtx);
+	std::lock_guard<std::mutex> lock(mtx);
 
 	unsigned int days = cfg->get_configvalue_as_int("keep-articles-days");
 	if (days > 0) {
@@ -886,10 +904,9 @@ void cache::clean_old_articles() {
 }
 
 void cache::fetch_descriptions(rss_feed * feed) {
-	std::vector<std::tr1::shared_ptr<rss_item> >& items = feed->items();
 	std::vector<std::string> guids;
-	for (std::vector<std::tr1::shared_ptr<rss_item> >::iterator it=items.begin();it!=items.end();++it) {
-		guids.push_back(prepare_query("'%q'", (*it)->guid().c_str()));
+	for (auto item : feed->items()) {
+		guids.push_back(prepare_query("'%q'", item->guid().c_str()));
 	}
 	std::string in_clause = utils::join(guids, ", ");
 
@@ -905,7 +922,7 @@ void cache::fetch_descriptions(rss_feed * feed) {
 }
 
 void cache::record_google_replay(const std::string& guid, unsigned int state) {
-	scope_mutex lock(&mtx);
+	std::lock_guard<std::mutex> lock(mtx);
 
 	std::string query = prepare_query("INSERT INTO google_replay ( guid, state, ts ) VALUES ( '%q', %u, %u );", guid.c_str(), state, (unsigned int)time(NULL));
 
@@ -916,8 +933,8 @@ void cache::record_google_replay(const std::string& guid, unsigned int state) {
 void cache::delete_google_replay_by_guid(const std::vector<std::string>& guids) {
 	std::vector<std::string> escaped_guids;
 
-	for (std::vector<std::string>::const_iterator it=guids.begin();it!=guids.end();++it) {
-		escaped_guids.push_back(prepare_query("'%q'", it->c_str()));
+	for (auto guid : guids) {
+		escaped_guids.push_back(prepare_query("'%q'", guid.c_str()));
 	}
 
 	std::string query = prepare_query("DELETE FROM google_replay WHERE guid IN ( %s );", utils::join(escaped_guids, ", ").c_str());
