@@ -44,9 +44,9 @@ void colormanager::handle_action(const std::string& action, const std::vector<st
 			throw confighandlerexception(utils::strprintf(_("`%s' is not a valid color"), fgcolor.c_str()));
 		if (!utils::is_valid_color(bgcolor))
 			throw confighandlerexception(utils::strprintf(_("`%s' is not a valid color"), bgcolor.c_str()));
-		
+
 		std::vector<std::string> attribs;
-		for (unsigned int i=3;i<params.size();++i) {
+		for (unsigned int i=3; i<params.size(); ++i) {
 			if (!utils::is_valid_attribute(params[i]))
 				throw confighandlerexception(utils::strprintf(_("`%s' is not a valid attribute"), params[i].c_str()));
 			attribs.push_back(params[i]);
@@ -54,25 +54,24 @@ void colormanager::handle_action(const std::string& action, const std::vector<st
 
 		/* we only allow certain elements to be configured, also to indicate the user possible mis-spellings */
 		if (element == "listnormal" || element == "listfocus" || element == "listnormal_unread" || element =="listfocus_unread"
-                || element == "info" || element == "background" || element == "article") {
+		        || element == "info" || element == "background" || element == "article") {
 			fg_colors[element] = fgcolor;
 			bg_colors[element] = bgcolor;
 			attributes[element] = attribs;
 			colors_loaded_ = true;
 		} else
-			throw confighandlerexception(utils::strprintf(_("`%s' is not a valid configuration element")));
+			throw confighandlerexception(utils::strprintf(_("`%s' is not a valid configuration element"), element.c_str()));
 
 	} else
 		throw confighandlerexception(AHS_INVALID_COMMAND);
 }
 
 void colormanager::dump_config(std::vector<std::string>& config_output) {
-	for (std::map<std::string, std::string>::iterator it=fg_colors.begin();it!=fg_colors.end();++it) {
-		std::string configline = utils::strprintf("color %s %s %s", it->first.c_str(), it->second.c_str(), bg_colors[it->first].c_str());
-		std::vector<std::string> attribs = attributes[it->first];
-		for (std::vector<std::string>::iterator jt=attribs.begin();jt!=attribs.end();++jt) {
+	for (auto color : fg_colors) {
+		std::string configline = utils::strprintf("color %s %s %s", color.first.c_str(), color.second.c_str(), bg_colors[color.first].c_str());
+		for (auto attrib : attributes[color.first]) {
 			configline.append(" ");
-			configline.append(*jt);
+			configline.append(attrib);
 		}
 		config_output.push_back(configline);
 	}
@@ -83,11 +82,11 @@ void colormanager::dump_config(std::vector<std::string>& config_output) {
  * TODO: refactor this
  */
 void colormanager::set_pb_colors(podbeuter::pb_view * v) {
-	std::map<std::string,std::string>::iterator fgcit = fg_colors.begin();
-	std::map<std::string,std::string>::iterator bgcit = bg_colors.begin();
-	std::map<std::string,std::vector<std::string> >::iterator attit = attributes.begin();
+	auto fgcit = fg_colors.begin();
+	auto bgcit = bg_colors.begin();
+	auto attit = attributes.begin();
 
-	for (;fgcit != fg_colors.end(); ++fgcit, ++bgcit, ++attit) {
+	for (; fgcit != fg_colors.end(); ++fgcit, ++bgcit, ++attit) {
 		std::string colorattr;
 		if (fgcit->second != "default") {
 			colorattr.append("fg=");
@@ -99,12 +98,12 @@ void colormanager::set_pb_colors(podbeuter::pb_view * v) {
 			colorattr.append("bg=");
 			colorattr.append(bgcit->second);
 		}
-		for (std::vector<std::string>::iterator it=attit->second.begin(); it!= attit->second.end(); ++it) {
+		for (auto attr : attit->second) {
 			if (colorattr.length() > 0)
 				colorattr.append(",");
 			colorattr.append("attr=");
-			colorattr.append(*it);
-		} 
+			colorattr.append(attr);
+		}
 
 		LOG(LOG_DEBUG,"colormanager::set_pb_colors: %s %s\n",fgcit->first.c_str(), colorattr.c_str());
 
@@ -113,7 +112,7 @@ void colormanager::set_pb_colors(podbeuter::pb_view * v) {
 
 		if (fgcit->first == "article") {
 			std::string styleend_str;
-			
+
 			if (bgcit->second != "default") {
 				styleend_str.append("bg=");
 				styleend_str.append(bgcit->second);
