@@ -13,10 +13,9 @@
 #include <pwd.h>
 
 
-namespace newsbeuter
-{
+namespace newsbeuter {
 
-configdata::configdata(const std::string& v, ...) : value(v), default_value(v), type(ENUM) {
+configdata::configdata(std::string v, ...) : value(v), default_value(v), type(ENUM) {
 	va_list ap;
 	va_start(ap, v);
 
@@ -32,8 +31,7 @@ configdata::configdata(const std::string& v, ...) : value(v), default_value(v),
 	va_end(ap);
 }
 
-configcontainer::configcontainer()
-{
+configcontainer::configcontainer() {
 	// create the config options and set their resp. default value and type
 	config_data["show-read-feeds"] = configdata("yes", configdata::BOOL);
 	config_data["browser"]         = configdata("lynx", configdata::PATH);
@@ -64,7 +62,7 @@ configcontainer::configcontainer()
 	config_data["notify-program"]  = configdata("", configdata::PATH);
 	config_data["notify-format"]   = configdata(_("newsbeuter: finished reload, %f unread feeds (%n unread articles total)"), configdata::STR);
 	config_data["datetime-format"] = configdata("%b %d", configdata::STR);
-	config_data["urls-source"]     = configdata("local", "local", "opml", "oldreader", "ttrss", "newsblur", NULL); // enum
+	config_data["urls-source"]     = configdata("local", "local", "opml", "oldreader", "ttrss", "newsblur", "feedhq", NULL); // enum
 	config_data["bookmark-cmd"]    = configdata("", configdata::STR);
 	config_data["opml-url"]        = configdata("", configdata::STR, true);
 	config_data["html-renderer"]   = configdata("internal", configdata::PATH);
@@ -100,11 +98,19 @@ configcontainer::configcontainer()
 	config_data["oldreader-flag-star"] = configdata("", configdata::STR);
 	config_data["oldreader-show-special-feeds"] = configdata("true", configdata::BOOL);
 	config_data["oldreader-min-items"] = configdata("20", configdata::INT);
+	config_data["feedhq-login"] = configdata("", configdata::STR);
+	config_data["feedhq-password"] = configdata("", configdata::STR);
+	config_data["feedhq-passwordfile"] = configdata("", configdata::PATH);
+	config_data["feedhq-flag-share"] = configdata("", configdata::STR);
+	config_data["feedhq-flag-star"] = configdata("", configdata::STR);
+	config_data["feedhq-show-special-feeds"] = configdata("true", configdata::BOOL);
+	config_data["feedhq-min-items"] = configdata("20", configdata::INT);
+	config_data["feedhq-url"] = configdata("https://feedhq.org/", configdata::STR);
 	config_data["ignore-mode"] = configdata("download", "download", "display", NULL); // enum
 	config_data["max-download-speed"] = configdata("0", configdata::INT);
-	config_data["cookie-cache"] = configdata("", configdata::STR);
+	config_data["cookie-cache"] = configdata("", configdata::PATH);
 	config_data["download-full-page"] = configdata("false", configdata::BOOL);
-	config_data["external-url-viewer"] = configdata("", configdata::STR);
+	config_data["external-url-viewer"] = configdata("", configdata::PATH);
 	config_data["ttrss-login"] = configdata("", configdata::STR);
 	config_data["ttrss-password"] = configdata("", configdata::STR);
 	config_data["ttrss-passwordfile"] = configdata("", configdata::PATH);
@@ -134,16 +140,14 @@ configcontainer::configcontainer()
 	config_data["dialogs-title-format"] = configdata(_("%N %V - Dialogs"), configdata::STR);
 }
 
-configcontainer::~configcontainer()
-{
+configcontainer::~configcontainer() {
 }
 
-void configcontainer::register_commands(configparser& cfgparser)
-{
+void configcontainer::register_commands(configparser& cfgparser) {
 	// this registers the config options defined above in the configuration parser
 	// -> if the resp. config option is encountered, it is passed to the configcontainer
-	for (std::map<std::string,configdata>::iterator it=config_data.begin();it!=config_data.end();++it) {
-		cfgparser.register_handler(it->first, this);
+	for (auto cfg : config_data) {
+		cfgparser.register_handler(cfg.first, this);
 	}
 }
 
@@ -165,33 +169,33 @@ void configcontainer::handle_action(const std::string& action, const std::vector
 	}
 
 	switch (cfgdata.type) {
-		case configdata::BOOL:
-			if (!is_bool(params[0]))
-				throw confighandlerexception(utils::strprintf(_("expected boolean value, found `%s' instead"), params[0].c_str()));
+	case configdata::BOOL:
+		if (!is_bool(params[0]))
+			throw confighandlerexception(utils::strprintf(_("expected boolean value, found `%s' instead"), params[0].c_str()));
+		cfgdata.value = params[0];
+		break;
+
+	case configdata::INT:
+		if (!is_int(params[0]))
+			throw confighandlerexception(utils::strprintf(_("expected integer value, found `%s' instead"), params[0].c_str()));
+		cfgdata.value = params[0];
+		break;
+
+	case configdata::ENUM:
+		if (cfgdata.enum_values.find(params[0]) == cfgdata.enum_values.end())
+			throw confighandlerexception(utils::strprintf(_("invalid configuration value `%s'"), params[0].c_str()));
+	// fall-through
+	case configdata::STR:
+	case configdata::PATH:
+		if (cfgdata.multi_option)
+			cfgdata.value = utils::join(params, " ");
+		else
 			cfgdata.value = params[0];
-			break;
+		break;
 
-		case configdata::INT:
-			if (!is_int(params[0]))
-				throw confighandlerexception(utils::strprintf(_("expected integer value, found `%s' instead"), params[0].c_str()));
-			cfgdata.value = params[0];
-			break;
-
-		case configdata::ENUM:
-			if (cfgdata.enum_values.find(params[0]) == cfgdata.enum_values.end())
-				throw confighandlerexception(utils::strprintf(_("invalid configuration value `%s'"), params[0].c_str()));
-			// fall-through
-		case configdata::STR:
-		case configdata::PATH:
-			if (cfgdata.multi_option)
-				cfgdata.value = utils::join(params, " ");
-			else
-				cfgdata.value = params[0];
-			break;
-
-		default:
-			// should not happen
-			throw confighandlerexception(AHS_INVALID_COMMAND);
+	default:
+		// should not happen
+		throw confighandlerexception(AHS_INVALID_COMMAND);
 	}
 }
 
@@ -215,7 +219,7 @@ std::string configcontainer::lookup_alias(const std::string& s) {
 
 bool configcontainer::is_int(const std::string& s) {
 	const char * s1 = s.c_str();
-	for (;*s1;s1++) {
+	for (; *s1; s1++) {
 		if (!isdigit(*s1))
 			return false;
 	}
@@ -263,28 +267,28 @@ void configcontainer::toggle(const std::string& key) {
 }
 
 void configcontainer::dump_config(std::vector<std::string>& config_output) {
-	for (std::map<std::string, configdata>::iterator it=config_data.begin();it!=config_data.end();++it) {
-		std::string configline = it->first + " ";
-		assert(it->second.type != configdata::INVALID);
-		switch (it->second.type) {
+	for (auto cfg : config_data) {
+		std::string configline = cfg.first + " ";
+		assert(cfg.second.type != configdata::INVALID);
+		switch (cfg.second.type) {
 		case configdata::BOOL:
 		case configdata::INT:
-			configline.append(it->second.value);
-			if (it->second.value != it->second.default_value)
-				configline.append(utils::strprintf(" # default: %s", it->second.default_value.c_str()));
+			configline.append(cfg.second.value);
+			if (cfg.second.value != cfg.second.default_value)
+				configline.append(utils::strprintf(" # default: %s", cfg.second.default_value.c_str()));
 			break;
 		case configdata::ENUM:
 		case configdata::STR:
 		case configdata::PATH:
-			if (it->second.multi_option) {
-				std::vector<std::string> tokens = utils::tokenize(it->second.value, " ");
-				for (std::vector<std::string>::iterator it=tokens.begin();it!=tokens.end();++it) {
-					configline.append(utils::quote(*it) + " ");
+			if (cfg.second.multi_option) {
+				std::vector<std::string> tokens = utils::tokenize(cfg.second.value, " ");
+				for (auto token : tokens) {
+					configline.append(utils::quote(token) + " ");
 				}
 			} else {
-				configline.append(utils::quote(it->second.value));
-				if (it->second.value != it->second.default_value) {
-					configline.append(utils::strprintf(" # default: %s", it->second.default_value.c_str()));
+				configline.append(utils::quote(cfg.second.value));
+				if (cfg.second.value != cfg.second.default_value) {
+					configline.append(utils::strprintf(" # default: %s", cfg.second.default_value.c_str()));
 				}
 			}
 			break;
@@ -292,6 +296,7 @@ void configcontainer::dump_config(std::vector<std::string>& config_output) {
 			// skip entry, generate no output
 			continue;
 		case configdata::INVALID:
+		default:
 			assert(0);
 			break;
 		}
@@ -301,9 +306,9 @@ void configcontainer::dump_config(std::vector<std::string>& config_output) {
 
 std::vector<std::string> configcontainer::get_suggestions(const std::string& fragment) {
 	std::vector<std::string> result;
-	for (std::map<std::string, configdata>::iterator it=config_data.begin();it!=config_data.end();++it) {
-		if (it->first.substr(0, fragment.length()) == fragment)
-			result.push_back(it->first);
+	for (auto cfg : config_data) {
+		if (cfg.first.substr(0, fragment.length()) == fragment)
+			result.push_back(cfg.first);
 	}
 	std::sort(result.begin(), result.end());
 	return result;
