@@ -15,6 +15,7 @@
 #include <rss_parser.h>
 #include <remote_api.h>
 #include <oldreader_api.h>
+#include <feedhq_api.h>
 #include <ttrss_api.h>
 #include <newsblur_api.h>
 #include <xlicense.h>
@@ -26,6 +27,7 @@
 #include <cerrno>
 #include <algorithm>
 #include <functional>
+#include <mutex>
 
 #include <sys/time.h>
 #include <ctime>
@@ -121,15 +123,13 @@ bool controller::setup_dirs_xdg(const char *env_home, bool silent) {
 	xdg_data_dir.append(NEWSBEUTER_PATH_SEP);
 	xdg_data_dir.append(NEWSBEUTER_SUBDIR_XDG);
 
-	if (access(xdg_config_dir.c_str(), R_OK | X_OK) != 0)
-	{
+	if (access(xdg_config_dir.c_str(), R_OK | X_OK) != 0) {
 		if (!silent) {
 			std::cerr << utils::strprintf(_("XDG: configuration directory '%s' not accessible, using '%s' instead."), xdg_config_dir.c_str(), config_dir.c_str()) << std::endl;
 		}
 		return false;
 	}
-	if (access(xdg_data_dir.c_str(), R_OK | X_OK | W_OK) != 0)
-	{
+	if (access(xdg_data_dir.c_str(), R_OK | X_OK | W_OK) != 0) {
 		if (!silent) {
 			std::cerr << utils::strprintf(_("XDG: data directory '%s' not accessible, using '%s' instead."), xdg_data_dir.c_str(), config_dir.c_str()) << std::endl;
 		}
@@ -189,10 +189,10 @@ controller::~controller() {
 	delete urlcfg;
 	delete api;
 
-	scope_mutex feedslock(&feeds_mutex);
-	for (std::vector<std::tr1::shared_ptr<rss_feed> >::iterator it=feeds.begin();it!=feeds.end();++it) {
-		scope_mutex lock(&((*it)->item_mutex));
-		(*it)->clear_items();
+	std::lock_guard<std::mutex> feedslock(feeds_mutex);
+	for (auto feed : feeds) {
+		std::lock_guard<std::mutex> lock(feed->item_mutex);
+		feed->clear_items();
 	}
 	feeds.clear();
 }
@@ -223,7 +223,7 @@ void controller::run(int argc, char * argv[]) {
 
 	do {
 		if ((c = ::getopt(argc,argv,getopt_str)) < 0)
-				continue;
+			continue;
 		if (strchr("iexq", c) != NULL) {
 			silent = true;
 			break;
@@ -238,83 +238,82 @@ void controller::run(int argc, char * argv[]) {
 		if((c = ::getopt(argc,argv,getopt_str))<0)
 			continue;
 		switch (c) {
-			case ':': /* fall-through */
-			case '?': /* missing option */
+		case ':': /* fall-through */
+		case '?': /* missing option */
+			usage(argv[0]);
+			break;
+		case 'i':
+			if (do_export)
 				usage(argv[0]);
-				break;
-			case 'i':
-				if (do_export)
-					usage(argv[0]);
-				do_import = true;
-				importfile = optarg;
-				break;
-			case 'r':
-				refresh_on_start = true;
-				break;
-			case 'e':
-				if (do_import)
-					usage(argv[0]);
-				do_export = true;
-				break;
-			case 'h':
+			do_import = true;
+			importfile = optarg;
+			break;
+		case 'r':
+			refresh_on_start = true;
+			break;
+		case 'e':
+			if (do_import)
 				usage(argv[0]);
-				break;
-			case 'u':
-				url_file = optarg;
-				break;
-			case 'c':
-				cache_file = optarg;
-				lock_file = std::string(cache_file) + LOCK_SUFFIX;
-				cachefile_given_on_cmdline = true;
-				break;
-			case 'C':
-				config_file = optarg;
-				break;
-			case 'X':
-				do_vacuum = true;
-				break;
-			case 'v':
-			case 'V':
-				show_version++;
-				break;
-			case 'o':
-				offline_mode = true;
-				break;
-			case 'x':
-				execute_cmds = true;
-				break;
-			case 'q':
-				break;
-			case 'd': // this is an undocumented debug commandline option!
-				logger::getInstance().set_logfile(optarg);
-				break;
-			case 'l': // this is an undocumented debug commandline option!
-				{
-					loglevel level = static_cast<loglevel>(atoi(optarg));
-					if (level > LOG_NONE && level <= LOG_DEBUG) {
-						logger::getInstance().set_loglevel(level);
-					} else {
-						std::cerr << utils::strprintf(_("%s: %d: invalid loglevel value"), argv[0], level) << std::endl;
-						::std::exit(EXIT_FAILURE);
-					}
-				}
-				break;
-			case 'I':
-				if (do_read_export)
-					usage(argv[0]);
-				do_read_import = true;
-				readinfofile = optarg;
-				break;
-			case 'E':
-				if (do_read_import)
-					usage(argv[0]);
-				do_read_export = true;
-				readinfofile = optarg;
-				break;
-			default:
-				std::cout << utils::strprintf(_("%s: unknown option - %c"), argv[0], static_cast<char>(c)) << std::endl;
+			do_export = true;
+			break;
+		case 'h':
+			usage(argv[0]);
+			break;
+		case 'u':
+			url_file = optarg;
+			break;
+		case 'c':
+			cache_file = optarg;
+			lock_file = std::string(cache_file) + LOCK_SUFFIX;
+			cachefile_given_on_cmdline = true;
+			break;
+		case 'C':
+			config_file = optarg;
+			break;
+		case 'X':
+			do_vacuum = true;
+			break;
+		case 'v':
+		case 'V':
+			show_version++;
+			break;
+		case 'o':
+			offline_mode = true;
+			break;
+		case 'x':
+			execute_cmds = true;
+			break;
+		case 'q':
+			break;
+		case 'd': // this is an undocumented debug commandline option!
+			logger::getInstance().set_logfile(optarg);
+			break;
+		case 'l': { // this is an undocumented debug commandline option!
+			loglevel level = static_cast<loglevel>(atoi(optarg));
+			if (level > LOG_NONE && level <= LOG_DEBUG) {
+				logger::getInstance().set_loglevel(level);
+			} else {
+				std::cerr << utils::strprintf(_("%s: %d: invalid loglevel value"), argv[0], level) << std::endl;
+				::std::exit(EXIT_FAILURE);
+			}
+		}
+		break;
+		case 'I':
+			if (do_read_export)
 				usage(argv[0]);
-				break;
+			do_read_import = true;
+			readinfofile = optarg;
+			break;
+		case 'E':
+			if (do_read_import)
+				usage(argv[0]);
+			do_read_export = true;
+			readinfofile = optarg;
+			break;
+		default:
+			std::cout << utils::strprintf(_("%s: unknown option - %c"), argv[0], static_cast<char>(c)) << std::endl;
+			usage(argv[0]);
+			break;
 		}
 	} while (c != -1);
 
@@ -356,7 +355,7 @@ void controller::run(int argc, char * argv[]) {
 	if (!silent)
 		std::cout << _("Loading configuration...");
 	std::cout.flush();
-	
+
 	cfg.register_commands(cfgparser);
 	colorman.register_commands(cfgparser);
 
@@ -380,7 +379,7 @@ void controller::run(int argc, char * argv[]) {
 		LOG(LOG_ERROR,"an exception occured while parsing the configuration file: %s",ex.what());
 		std::cout << ex.what() << std::endl;
 		utils::remove_fs_lock(lock_file);
-		return;	
+		return;
 	}
 
 	update_config();
@@ -441,11 +440,15 @@ void controller::run(int argc, char * argv[]) {
 		real_offline_mode = offline_mode;
 	} else if (type == "ttrss") {
 		api = new ttrss_api(&cfg);
-		urlcfg = new ttrss_urlreader(&cfg, url_file, api);
+		urlcfg = new ttrss_urlreader(url_file, api);
 		real_offline_mode = offline_mode;
 	} else if (type == "newsblur") {
 		api = new newsblur_api(&cfg);
-		urlcfg = new newsblur_urlreader(&cfg, url_file, api);
+		urlcfg = new newsblur_urlreader(url_file, api);
+		real_offline_mode = offline_mode;
+	} else if (type == "feedhq") {
+		api = new feedhq_api(&cfg);
+		urlcfg = new feedhq_urlreader(&cfg, url_file, api);
 		real_offline_mode = offline_mode;
 	} else {
 		LOG(LOG_ERROR,"unknown urls-source `%s'", urlcfg->get_source().c_str());
@@ -517,25 +520,24 @@ void controller::run(int argc, char * argv[]) {
 	}
 
 	unsigned int i=0;
-	for (std::vector<std::string>::const_iterator it=urlcfg->get_urls().begin(); it != urlcfg->get_urls().end(); ++it, ++i) {
-		std::tr1::shared_ptr<rss_feed> feed(new rss_feed(rsscache));
+	for (auto url : urlcfg->get_urls()) {
 		try {
-			feed->set_rssurl(*it);
-			feed->set_tags(urlcfg->get_tags(*it));
 			bool ignore_disp = (cfg.get_configvalue("ignore-mode") == "display");
-			rsscache->internalize_rssfeed(feed, ignore_disp ? &ign : NULL);
+			std::shared_ptr<rss_feed> feed = rsscache->internalize_rssfeed(url, ignore_disp ? &ign : NULL);
+			feed->set_tags(urlcfg->get_tags(url));
+			feed->set_order(i);
+			std::lock_guard<std::mutex> feedslock(feeds_mutex);
+			feeds.push_back(feed);
 		} catch(const dbexception& e) {
 			std::cout << _("Error while loading feeds from database: ") << e.what() << std::endl;
 			utils::remove_fs_lock(lock_file);
 			return;
 		} catch(const std::string& str) {
-			std::cout << utils::strprintf(_("Error while loading feed '%s': %s"), it->c_str(), str.c_str()) << std::endl;
+			std::cout << utils::strprintf(_("Error while loading feed '%s': %s"), url.c_str(), str.c_str()) << std::endl;
 			utils::remove_fs_lock(lock_file);
 			return;
 		}
-		feed->set_order(i);
-		scope_mutex feedslock(&feeds_mutex);
-		feeds.push_back(feed);
+		i++;
 	}
 
 	sort_feeds();
@@ -549,10 +551,10 @@ void controller::run(int argc, char * argv[]) {
 	if (cfg.get_configvalue_as_bool("prepopulate-query-feeds")) {
 		std::cout << _("Prepopulating query feeds...");
 		std::cout.flush();
-		scope_mutex feedslock(&feeds_mutex);
-		for (std::vector<std::tr1::shared_ptr<rss_feed> >::iterator it=feeds.begin();it!=feeds.end();++it) {
-			if ((*it)->rssurl().substr(0,6) == "query:") {
-				(*it)->update_items(get_all_feeds_unlocked());
+		std::lock_guard<std::mutex> feedslock(feeds_mutex);
+		for (auto feed : feeds) {
+			if (feed->rssurl().substr(0,6) == "query:") {
+				feed->update_items(get_all_feeds_unlocked());
 			}
 		}
 		std::cout << _("done.") << std::endl;
@@ -613,7 +615,7 @@ void controller::run(int argc, char * argv[]) {
 		std::cout.flush();
 	}
 	try {
-		scope_mutex feedslock(&feeds_mutex);
+		std::lock_guard<std::mutex> feedslock(feeds_mutex);
 		rsscache->cleanup_cache(feeds);
 		if (!silent) {
 			std::cout << _("done.") << std::endl;
@@ -629,12 +631,12 @@ void controller::run(int argc, char * argv[]) {
 }
 
 void controller::update_feedlist() {
-	scope_mutex feedslock(&feeds_mutex);
+	std::lock_guard<std::mutex> feedslock(feeds_mutex);
 	v->set_feedlist(feeds);
 }
 
 void controller::update_visible_feeds() {
-	scope_mutex feedslock(&feeds_mutex);
+	std::lock_guard<std::mutex> feedslock(feeds_mutex);
 	v->update_visible_feeds(feeds);
 }
 
@@ -645,15 +647,15 @@ void controller::catchup_all() {
 		v->show_error(utils::strprintf(_("Error: couldn't mark all feeds read: %s"), e.what()));
 		return;
 	}
-	scope_mutex feedslock(&feeds_mutex);
-	for (std::vector<std::tr1::shared_ptr<rss_feed> >::iterator it=feeds.begin();it!=feeds.end();++it) {
-		scope_mutex lock(&(*it)->item_mutex);
-		if ((*it)->items().size() > 0) {
+	std::lock_guard<std::mutex> feedslock(feeds_mutex);
+	for (auto feed : feeds) {
+		std::lock_guard<std::mutex> lock(feed->item_mutex);
+		if (feed->items().size() > 0) {
 			if (api) {
-				api->mark_all_read((*it)->rssurl());
+				api->mark_all_read(feed->rssurl());
 			}
-			for (std::vector<std::tr1::shared_ptr<rss_item> >::iterator jt=(*it)->items().begin();jt!=(*it)->items().end();++jt) {
-				(*jt)->set_unread_nowrite(false);
+			for (auto item : feed->items()) {
+				item->set_unread_nowrite(false);
 			}
 		}
 	}
@@ -677,8 +679,8 @@ void controller::record_google_replay(const std::string& guid, bool read) {
 void controller::mark_all_read(unsigned int pos) {
 	if (pos < feeds.size()) {
 		scope_measure m("controller::mark_all_read");
-		scope_mutex feedslock(&feeds_mutex);
-		std::tr1::shared_ptr<rss_feed> feed = feeds[pos];
+		std::lock_guard<std::mutex> feedslock(feeds_mutex);
+		std::shared_ptr<rss_feed> feed = feeds[pos];
 		if (feed->rssurl().substr(0,6) == "query:") {
 			rsscache->catchup_all(feed);
 		} else {
@@ -688,14 +690,13 @@ void controller::mark_all_read(unsigned int pos) {
 			}
 		}
 		m.stopover("after rsscache->catchup_all, before iteration over items");
-		scope_mutex lock(&feed->item_mutex);
-		std::vector<std::tr1::shared_ptr<rss_item> >& items = feed->items();
-		std::vector<std::tr1::shared_ptr<rss_item> >::iterator begin = items.begin(), end = items.end();
+		std::lock_guard<std::mutex> lock(feed->item_mutex);
+		std::vector<std::shared_ptr<rss_item>>& items = feed->items();
 		if (items.size() > 0) {
 			bool notify = items[0]->feedurl() != feed->rssurl();
 			LOG(LOG_DEBUG, "controller::mark_all_read: notify = %s", notify ? "yes" : "no");
-			for (std::vector<std::tr1::shared_ptr<rss_item> >::iterator it=begin;it!=end;++it) {
-				(*it)->set_unread_nowrite_notify(false, notify);
+			for (auto item : items) {
+				item->set_unread_nowrite_notify(false, notify);
 			}
 		}
 	}
@@ -704,7 +705,7 @@ void controller::mark_all_read(unsigned int pos) {
 void controller::reload(unsigned int pos, unsigned int max, bool unattended, curl_handle *easyhandle) {
 	LOG(LOG_DEBUG, "controller::reload: pos = %u max = %u", pos, max);
 	if (pos < feeds.size()) {
-		std::tr1::shared_ptr<rss_feed> oldfeed = feeds[pos];
+		std::shared_ptr<rss_feed> oldfeed = feeds[pos];
 		std::string errmsg;
 		if (!unattended)
 			v->set_status(utils::strprintf(_("%sLoading %s..."), prepare_message(pos+1, max).c_str(), utils::censor_url(oldfeed->rssurl()).c_str()));
@@ -716,11 +717,23 @@ void controller::reload(unsigned int pos, unsigned int max, bool unattended, cur
 		LOG(LOG_DEBUG, "controller::reload: created parser");
 		try {
 			oldfeed->set_status(DURING_DOWNLOAD);
-			std::tr1::shared_ptr<rss_feed> newfeed = parser.parse();
+			std::shared_ptr<rss_feed> newfeed = parser.parse();
 			if (newfeed->items().size() > 0) {
-				scope_mutex feedslock(&feeds_mutex);
+				std::lock_guard<std::mutex> feedslock(feeds_mutex);
 				save_feed(newfeed, pos);
 				enqueue_items(newfeed);
+
+				newfeed->clear_items();
+
+				bool ignore_disp = (cfg.get_configvalue("ignore-mode") == "display");
+				std::shared_ptr<rss_feed> feed = rsscache->internalize_rssfeed(oldfeed->rssurl(), ignore_disp ? &ign : NULL);
+				feed->set_tags(urlcfg->get_tags(oldfeed->rssurl()));
+				feed->set_order(oldfeed->get_order());
+				feeds[pos] = feed;
+
+				oldfeed->clear_items();
+
+				v->notify_itemlist_change(feeds[pos]);
 				if (!unattended) {
 					v->set_feedlist(feeds);
 				}
@@ -746,12 +759,12 @@ void controller::reload(unsigned int pos, unsigned int max, bool unattended, cur
 	}
 }
 
-std::tr1::shared_ptr<rss_feed> controller::get_feed(unsigned int pos) {
-	scope_mutex feedslock(&feeds_mutex);
+std::shared_ptr<rss_feed> controller::get_feed(unsigned int pos) {
+	std::lock_guard<std::mutex> feedslock(feeds_mutex);
 	if (pos >= feeds.size()) {
 		throw std::out_of_range(_("invalid feed index (bug)"));
 	}
-	std::tr1::shared_ptr<rss_feed> feed = feeds[pos];
+	std::shared_ptr<rss_feed> feed = feeds[pos];
 	return feed;
 }
 
@@ -762,12 +775,12 @@ void controller::reload_indexes(const std::vector<int>& indexes, bool unattended
 
 	unsigned long size;
 	{
-		scope_mutex feedslock(&feeds_mutex);
+		std::lock_guard<std::mutex> feedslock(feeds_mutex);
 		size = feeds.size();
 	}
 
-	for (std::vector<int>::const_iterator it=indexes.begin();it!=indexes.end();++it) {
-		this->reload(*it, size, unattended);
+	for (auto idx : indexes) {
+		this->reload(idx, size, unattended);
 	}
 
 	unsigned int unread_feeds2, unread_articles2;
@@ -785,48 +798,34 @@ void controller::reload_indexes(const std::vector<int>& indexes, bool unattended
 		v->set_status("");
 }
 
-struct feed_cmp {
-	const std::vector<std::tr1::shared_ptr<rss_feed> > &feeds;
-	feed_cmp(const std::vector<std::tr1::shared_ptr<rss_feed> > &f)
-		: feeds(f)
-	{
-	}
-	void extract(std::string &s, const std::string &url) const
-	{
+void controller::reload_range(unsigned int start, unsigned int end, unsigned int size, bool unattended) {
+
+	std::vector<unsigned int> v;
+	for (unsigned int i=start; i<=end; ++i)
+		v.push_back(i);
+
+	auto extract = [](std::string& s, const std::string& url) {
 		size_t p = url.find("//");
 		p = (p == std::string::npos) ? 0 : p+2;
 		std::string suff(url.substr(p));
 		p = suff.find('/');
 		s = suff.substr(0, p);
-	}
-	bool operator()(unsigned a, unsigned b) const
-	{
-		std::tr1::shared_ptr<rss_feed> x = feeds[a];
-		std::tr1::shared_ptr<rss_feed> y = feeds[b];
-		const std::string &u = x->rssurl();
-		const std::string &v = y->rssurl();
-		
+	};
+
+	std::sort(v.begin(), v.end(), [&](unsigned int a, unsigned int b) {
 		std::string domain1, domain2;
-		extract(domain1, u);
-		extract(domain2, v);
+		extract(domain1, feeds[a]->rssurl());
+		extract(domain2, feeds[b]->rssurl());
 		std::reverse(domain1.begin(), domain1.end());
 		std::reverse(domain2.begin(), domain2.end());
 		return domain1 < domain2;
-	}
-};
-
-void controller::reload_range(unsigned int start, unsigned int end, unsigned int size, bool unattended) {
-
-	std::vector<unsigned> v;
-	for (unsigned i=start;i<=end;++i)
-		v.push_back(i);
-	std::sort(v.begin(), v.end(), feed_cmp(feeds));
+	});
 
 	curl_handle easyhandle;
 
-	for (std::vector<unsigned>::iterator i = v.begin(); i!= v.end(); ++i) {
-		LOG(LOG_DEBUG, "controller::reload_range: reloading feed #%u", *i);
-		this->reload(*i, size, unattended, &easyhandle);
+	for (auto i : v) {
+		LOG(LOG_DEBUG, "controller::reload_range: reloading feed #%u", i);
+		this->reload(i, size, unattended, &easyhandle);
 	}
 }
 
@@ -839,9 +838,9 @@ void controller::reload_all(bool unattended) {
 	unsigned int size;
 
 	{
-		scope_mutex feedlock(&feeds_mutex);
-		for (std::vector<std::tr1::shared_ptr<rss_feed> >::iterator it=feeds.begin();it!=feeds.end();++it) {
-			(*it)->reset_status();
+		std::lock_guard<std::mutex> feedlock(feeds_mutex);
+		for (auto feed : feeds) {
+			feed->reset_status();
 		}
 		size = feeds.size();
 	}
@@ -860,25 +859,24 @@ void controller::reload_all(bool unattended) {
 	if (num_threads <= 1) {
 		this->reload_range(0, size-1, size, unattended);
 	} else {
-		std::vector<std::pair<unsigned int, unsigned int> > partitions = utils::partition_indexes(0, size-1, num_threads);
-		std::vector<pthread_t> threads;
+		std::vector<std::pair<unsigned int, unsigned int>> partitions = utils::partition_indexes(0, size-1, num_threads);
+		std::vector<std::thread> threads;
 		LOG(LOG_DEBUG, "controller::reload_all: starting reload threads...");
-		for (unsigned int i=0;i<num_threads-1;i++) {
-			reloadrangethread* t = new reloadrangethread(this, partitions[i].first, partitions[i].second, size, unattended);
-			threads.push_back(t->start());
+		for (unsigned int i=0; i<num_threads-1; i++) {
+			threads.push_back(std::thread(reloadrangethread(this, partitions[i].first, partitions[i].second, size, unattended)));
 		}
 		LOG(LOG_DEBUG, "controller::reload_all: starting my own reload...");
 		this->reload_range(partitions[num_threads-1].first, partitions[num_threads-1].second, size, unattended);
 		LOG(LOG_DEBUG, "controller::reload_all: joining other threads...");
-		for (std::vector<pthread_t>::iterator it=threads.begin();it!=threads.end();++it) {
-			::pthread_join(*it, NULL);
+		for (size_t i=0; i<threads.size(); i++) {
+			threads[i].join();
 		}
 	}
 
 	// refresh query feeds (update and sort)
 	LOG(LOG_DEBUG, "controller::reload_all: refresh query feeds");
-	for (std::vector<std::tr1::shared_ptr<rss_feed> >::iterator it=feeds.begin();it!=feeds.end();++it) {
-		v->prepare_query_feed(*it);
+	for (auto feed : feeds) {
+		v->prepare_query_feed(feed);
 	}
 	v->force_redraw();
 
@@ -933,8 +931,8 @@ void controller::notify(const std::string& msg) {
 void controller::compute_unread_numbers(unsigned int& unread_feeds, unsigned int& unread_articles) {
 	unread_feeds = 0;
 	unread_articles = 0;
-	for (std::vector<std::tr1::shared_ptr<rss_feed> >::iterator it=feeds.begin();it!=feeds.end();++it) {
-		unsigned int items = (*it)->unread_item_count();
+	for (auto feed : feeds) {
+		unsigned int items = feed->unread_item_count();
 		if (items > 0) {
 			++unread_feeds;
 			unread_articles += items;
@@ -943,7 +941,7 @@ void controller::compute_unread_numbers(unsigned int& unread_feeds, unsigned int
 }
 
 bool controller::trylock_reload_mutex() {
-	if (reload_mutex.trylock()) {
+	if (reload_mutex.try_lock()) {
 		LOG(LOG_DEBUG, "controller::trylock_reload_mutex succeeded");
 		return true;
 	}
@@ -953,8 +951,8 @@ bool controller::trylock_reload_mutex() {
 
 void controller::start_reload_all_thread(std::vector<int> * indexes) {
 	LOG(LOG_INFO,"starting reload all thread");
-	thread * dlt = new downloadthread(this, indexes);
-	dlt->start();
+	std::thread t(downloadthread(this, indexes));
+	t.detach();
 }
 
 void controller::version_information(const char * argv0, unsigned int level) {
@@ -992,8 +990,8 @@ static unsigned int gentabs(const std::string& str) {
 }
 
 void controller::usage(char * argv0) {
-	std::cout << utils::strprintf(_("%s %s\nusage: %s [-i <file>|-e] [-u <urlfile>] [-c <cachefile>] [-x <command> ...] [-h]\n"), 
-					PROGRAM_NAME, PROGRAM_VERSION, argv0);
+	std::cout << utils::strprintf(_("%s %s\nusage: %s [-i <file>|-e] [-u <urlfile>] [-c <cachefile>] [-x <command> ...] [-h]\n"),
+	                              PROGRAM_NAME, PROGRAM_VERSION, argv0);
 	struct {
 		char arg;
 		const char * params;
@@ -1018,10 +1016,10 @@ void controller::usage(char * argv0) {
 		{ '\0', NULL, NULL }
 	};
 
-	for (unsigned int i=0;args[i].arg != '\0';i++) {
+	for (unsigned int i=0; args[i].arg != '\0'; i++) {
 		unsigned int tabs = gentabs(args[i].params);
 		std::cout << "\t-" << args[i].arg << " " << args[i].params;
-		for (unsigned int j=0;j<tabs;j++) { 
+		for (unsigned int j=0; j<tabs; j++) {
 			std::cout << "\t";
 		}
 		std::cout << args[i].desc << std::endl;
@@ -1060,11 +1058,11 @@ void controller::export_opml() {
 	xmlNewTextChild(head, NULL, (const xmlChar *)"title", (const xmlChar *)PROGRAM_NAME " - Exported Feeds");
 	xmlNodePtr body = xmlNewTextChild(opml_node, NULL, (const xmlChar *)"body", NULL);
 
-	for (std::vector<std::tr1::shared_ptr<rss_feed> >::iterator it=feeds.begin(); it != feeds.end(); ++it) {
-		if (!utils::is_special_url((*it)->rssurl())) {
-			std::string rssurl = (*it)->rssurl();
-			std::string link = (*it)->link();
-			std::string title = (*it)->title();
+	for (auto feed : feeds) {
+		if (!utils::is_special_url(feed->rssurl())) {
+			std::string rssurl = feed->rssurl();
+			std::string link = feed->link();
+			std::string title = feed->title();
 
 			xmlNodePtr outline = xmlNewTextChild(body, NULL, (const xmlChar *)"outline", NULL);
 			xmlSetProp(outline, (const xmlChar *)"type", (const xmlChar *)"rss");
@@ -1121,8 +1119,8 @@ void controller::rec_find_rss_outlines(xmlNode * node, std::string tag) {
 
 				LOG(LOG_DEBUG, "OPML import: size = %u", urlcfg->get_urls().size());
 				if (urlcfg->get_urls().size() > 0) {
-					for (std::vector<std::string>::iterator it = urlcfg->get_urls().begin(); it != urlcfg->get_urls().end(); ++it) {
-						if (*it == url) {
+					for (auto u : urlcfg->get_urls()) {
+						if (u == url) {
 							found = true;
 						}
 					}
@@ -1160,28 +1158,29 @@ void controller::rec_find_rss_outlines(xmlNode * node, std::string tag) {
 
 
 
-std::vector<std::tr1::shared_ptr<rss_item> > controller::search_for_items(const std::string& query, const std::string& feedurl) {
-	std::vector<std::tr1::shared_ptr<rss_item> > items = rsscache->search_for_items(query, feedurl);
+std::vector<std::shared_ptr<rss_item>> controller::search_for_items(const std::string& query, const std::string& feedurl) {
+	std::vector<std::shared_ptr<rss_item>> items = rsscache->search_for_items(query, feedurl);
 	LOG(LOG_DEBUG, "controller::search_for_items: setting feed pointers");
-	for (std::vector<std::tr1::shared_ptr<rss_item> >::iterator it=items.begin();it!=items.end();++it) {
-		(*it)->set_feedptr(get_feed_by_url((*it)->feedurl()));
+	for (auto item : items) {
+		item->set_feedptr(get_feed_by_url(item->feedurl()));
 	}
 	return items;
 }
 
-std::tr1::shared_ptr<rss_feed> controller::get_feed_by_url(const std::string& feedurl) {
-	for (std::vector<std::tr1::shared_ptr<rss_feed> >::iterator it=feeds.begin();it!=feeds.end();++it) {
-		if (feedurl == (*it)->rssurl())
-			return *it;
+std::shared_ptr<rss_feed> controller::get_feed_by_url(const std::string& feedurl) {
+	for (auto feed : feeds) {
+		if (feedurl == feed->rssurl())
+			return feed;
 	}
-	return std::tr1::shared_ptr<rss_feed>();
+	LOG(LOG_ERROR, "controller:get_feed_by_url failed for %s", feedurl.c_str());
+	return std::shared_ptr<rss_feed>();
 }
 
 bool controller::is_valid_podcast_type(const std::string& /* mimetype */) {
 	return true;
 }
 
-void controller::enqueue_url(const std::string& url, std::tr1::shared_ptr<rss_feed> feed) {
+void controller::enqueue_url(const std::string& url, std::shared_ptr<rss_feed> feed) {
 	bool url_found = false;
 	std::fstream f;
 	f.open(queue_file.c_str(), std::fstream::in);
@@ -1209,43 +1208,39 @@ void controller::enqueue_url(const std::string& url, std::tr1::shared_ptr<rss_fe
 
 void controller::reload_urls_file() {
 	urlcfg->reload();
-	std::vector<std::tr1::shared_ptr<rss_feed> > new_feeds;
+	std::vector<std::shared_ptr<rss_feed>> new_feeds;
 	unsigned int i = 0;
 
-	for (std::vector<std::string>::const_iterator it=urlcfg->get_urls().begin();it!=urlcfg->get_urls().end();++it,++i) {
+	for (auto url : urlcfg->get_urls()) {
 		bool found = false;
-		for (std::vector<std::tr1::shared_ptr<rss_feed> >::iterator jt=feeds.begin();jt!=feeds.end();++jt) {
-			if (*it == (*jt)->rssurl()) {
+		for (auto feed : feeds) {
+			if (url == feed->rssurl()) {
 				found = true;
-				(*jt)->set_tags(urlcfg->get_tags(*it));
-				(*jt)->set_order(i);
-				new_feeds.push_back(*jt);
+				feed->set_tags(urlcfg->get_tags(url));
+				feed->set_order(i);
+				new_feeds.push_back(feed);
 				break;
 			}
 		}
 		if (!found) {
-			std::tr1::shared_ptr<rss_feed> new_feed(new rss_feed(rsscache));
-			try {
-				new_feed->set_rssurl(*it);
-			} catch (const std::string& str) {
-				LOG(LOG_USERERROR, "ignored invalid RSS URL '%s'", it->c_str());
-				continue;
-			}
-			new_feed->set_tags(urlcfg->get_tags(*it));
-			new_feed->set_order(i);
 			try {
 				bool ignore_disp = (cfg.get_configvalue("ignore-mode") == "display");
-				rsscache->internalize_rssfeed(new_feed, ignore_disp ? &ign : NULL);
+				std::shared_ptr<rss_feed> new_feed = rsscache->internalize_rssfeed(url, ignore_disp ? &ign : NULL);
+				new_feed->set_tags(urlcfg->get_tags(url));
+				new_feed->set_order(i);
+				new_feeds.push_back(new_feed);
 			} catch(const dbexception& e) {
 				LOG(LOG_ERROR, "controller::reload_urls_file: caught exception: %s", e.what());
 				throw;
 			}
-			new_feeds.push_back(new_feed);
 		}
+		i++;
 	}
 
+	v->set_tags(urlcfg->get_alltags());
+
 	{
-		scope_mutex feedslock(&feeds_mutex);
+		std::lock_guard<std::mutex> feedslock(feeds_mutex);
 		feeds = new_feeds;
 	}
 
@@ -1280,9 +1275,9 @@ std::string controller::bookmark(const std::string& url, const std::string& titl
 	std::string bookmark_cmd = cfg.get_configvalue("bookmark-cmd");
 	bool is_interactive = cfg.get_configvalue_as_bool("bookmark-interactive");
 	if (bookmark_cmd.length() > 0) {
-		std::string cmdline = utils::strprintf("%s '%s' %s %s", 
-			bookmark_cmd.c_str(), utils::replace_all(url,"'", "%27").c_str(), 
-			stfl::quote(title).c_str(), stfl::quote(description).c_str());
+		std::string cmdline = utils::strprintf("%s '%s' %s %s",
+		                                       bookmark_cmd.c_str(), utils::replace_all(url,"'", "%27").c_str(),
+		                                       stfl::quote(title).c_str(), stfl::quote(description).c_str());
 
 		LOG(LOG_DEBUG, "controller::bookmark: cmd = %s", cmdline.c_str());
 
@@ -1308,7 +1303,7 @@ std::string controller::bookmark(const std::string& url, const std::string& titl
 void controller::execute_commands(char ** argv, unsigned int i) {
 	if (v->formaction_stack_size() > 0)
 		v->pop_current_formaction();
-	for (;argv[i];++i) {
+	for (; argv[i]; ++i) {
 		LOG(LOG_DEBUG, "controller::execute_commands: executing `%s'", argv[i]);
 		std::string cmd(argv[i]);
 		if (cmd == "reload") {
@@ -1322,7 +1317,7 @@ void controller::execute_commands(char ** argv, unsigned int i) {
 	}
 }
 
-std::string controller::write_temporary_item(std::tr1::shared_ptr<rss_item> item) {
+std::string controller::write_temporary_item(std::shared_ptr<rss_item> item) {
 	char filename[1024];
 	snprintf(filename, sizeof(filename), "/tmp/newsbeuter-article.XXXXXX");
 	int fd = mkstemp(filename);
@@ -1335,7 +1330,7 @@ std::string controller::write_temporary_item(std::tr1::shared_ptr<rss_item> item
 	}
 }
 
-void controller::write_item(std::tr1::shared_ptr<rss_item> item, const std::string& filename) {
+void controller::write_item(std::shared_ptr<rss_item> item, const std::string& filename) {
 	std::fstream f;
 	f.open(filename.c_str(),std::fstream::out);
 	if (!f.is_open())
@@ -1344,18 +1339,18 @@ void controller::write_item(std::tr1::shared_ptr<rss_item> item, const std::stri
 	write_item(item, f);
 }
 
-void controller::write_item(std::tr1::shared_ptr<rss_item> item, std::ostream& ostr) {
+void controller::write_item(std::shared_ptr<rss_item> item, std::ostream& ostr) {
 	std::vector<std::string> lines;
 	std::vector<linkpair> links; // not used
-	
+
 	std::string title(_("Title: "));
 	title.append(item->title());
 	lines.push_back(title);
-	
+
 	std::string author(_("Author: "));
 	author.append(item->author());
 	lines.push_back(author);
-	
+
 	std::string date(_("Date: "));
 	date.append(item->pubDate());
 	lines.push_back(date);
@@ -1369,17 +1364,17 @@ void controller::write_item(std::tr1::shared_ptr<rss_item> item, std::ostream& o
 		dlurl.append(item->enclosure_url());
 		lines.push_back(dlurl);
 	}
-	
+
 	lines.push_back(std::string(""));
-	
+
 	unsigned int width = cfg.get_configvalue_as_int("text-width");
 	if (width == 0)
 		width = 80;
 	htmlrenderer rnd(width, true);
 	rnd.render(item->description(), lines, links, item->feedurl());
 
-	for (std::vector<std::string>::iterator it=lines.begin();it!=lines.end();++it) {
-		ostr << *it << std::endl;
+	for (auto l : lines) {
+		ostr << l << std::endl;
 	}
 }
 
@@ -1394,17 +1389,22 @@ std::string controller::prepare_message(unsigned int pos, unsigned int max) {
 	return "";
 }
 
-void controller::save_feed(std::tr1::shared_ptr<rss_feed> feed, unsigned int pos) {
+void controller::save_feed(std::shared_ptr<rss_feed> feed, unsigned int pos) {
 	if (!feed->is_empty()) {
 		LOG(LOG_DEBUG, "controller::save_feed: feed is nonempty, saving");
 		rsscache->externalize_rssfeed(feed, ign.matches_resetunread(feed->rssurl()));
 		LOG(LOG_DEBUG, "controller::save_feed: after externalize_rssfeed");
 
 		bool ignore_disp = (cfg.get_configvalue("ignore-mode") == "display");
-		rsscache->internalize_rssfeed(feed, ignore_disp ? &ign : NULL);
+		feed = rsscache->internalize_rssfeed(feed->rssurl(), ignore_disp ? &ign : NULL);
 		LOG(LOG_DEBUG, "controller::save_feed: after internalize_rssfeed");
 		feed->set_tags(urlcfg->get_tags(feed->rssurl()));
-		feed->set_order(feeds[pos]->get_order());
+		{
+			unsigned int order = feeds[pos]->get_order();
+			std::lock_guard<std::mutex> itemlock(feeds[pos]->item_mutex);
+			feeds[pos]->clear_items();
+			feed->set_order(order);
+		}
 		feeds[pos] = feed;
 		v->notify_itemlist_change(feeds[pos]);
 	} else {
@@ -1412,24 +1412,24 @@ void controller::save_feed(std::tr1::shared_ptr<rss_feed> feed, unsigned int pos
 	}
 }
 
-void controller::enqueue_items(std::tr1::shared_ptr<rss_feed> feed) {
+void controller::enqueue_items(std::shared_ptr<rss_feed> feed) {
 	if (!cfg.get_configvalue_as_bool("podcast-auto-enqueue"))
 		return;
-	scope_mutex lock(&feed->item_mutex);
-	for (std::vector<std::tr1::shared_ptr<rss_item> >::iterator it=feed->items().begin();it!=feed->items().end();++it) {
-		if (!(*it)->enqueued() && (*it)->enclosure_url().length() > 0) {
-			LOG(LOG_DEBUG, "controller::enqueue_items: enclosure_url = `%s' enclosure_type = `%s'", (*it)->enclosure_url().c_str(), (*it)->enclosure_type().c_str());
-			if (is_valid_podcast_type((*it)->enclosure_type()) && utils::is_http_url((*it)->enclosure_url())) {
-				LOG(LOG_INFO, "controller::enqueue_items: enqueuing `%s'", (*it)->enclosure_url().c_str());
-				enqueue_url((*it)->enclosure_url(), feed);
-				(*it)->set_enqueued(true);
-				rsscache->update_rssitem_unread_and_enqueued(*it, feed->rssurl());
+	std::lock_guard<std::mutex> lock(feed->item_mutex);
+	for (auto item : feed->items()) {
+		if (!item->enqueued() && item->enclosure_url().length() > 0) {
+			LOG(LOG_DEBUG, "controller::enqueue_items: enclosure_url = `%s' enclosure_type = `%s'", item->enclosure_url().c_str(), item->enclosure_type().c_str());
+			if (is_valid_podcast_type(item->enclosure_type()) && utils::is_http_url(item->enclosure_url())) {
+				LOG(LOG_INFO, "controller::enqueue_items: enqueuing `%s'", item->enclosure_url().c_str());
+				enqueue_url(item->enclosure_url(), feed);
+				item->set_enqueued(true);
+				rsscache->update_rssitem_unread_and_enqueued(item, feed->rssurl());
 			}
 		}
 	}
 }
 
-std::string controller::generate_enqueue_filename(const std::string& url, std::tr1::shared_ptr<rss_feed> feed) {
+std::string controller::generate_enqueue_filename(const std::string& url, std::shared_ptr<rss_feed> feed) {
 	std::string dlformat = cfg.get_configvalue("download-path");
 	if (dlformat[dlformat.length()-1] != NEWSBEUTER_PATH_SEP[0])
 		dlformat.append(NEWSBEUTER_PATH_SEP);
@@ -1486,68 +1486,42 @@ void controller::export_read_information(const std::string& readinfofile) {
 	std::fstream f;
 	f.open(readinfofile.c_str(), std::fstream::out);
 	if (f.is_open()) {
-		for (std::vector<std::string>::iterator it=guids.begin();it!=guids.end();++it) {
-			f << *it << std::endl;
+		for (auto guid : guids) {
+			f << guid << std::endl;
 		}
 	}
 }
 
-struct sort_feeds_by_firsttag : public std::binary_function<std::tr1::shared_ptr<rss_feed>, std::tr1::shared_ptr<rss_feed>, bool> {
-	sort_feeds_by_firsttag() { }
-	bool operator()(std::tr1::shared_ptr<rss_feed> a, std::tr1::shared_ptr<rss_feed> b) {
-		if (a->get_firsttag().length() == 0 || b->get_firsttag().length() == 0) {
-			return a->get_firsttag().length() > b->get_firsttag().length();
-		}
-		return strcasecmp(a->get_firsttag().c_str(), b->get_firsttag().c_str()) < 0;
-	}
-};
-
-struct sort_feeds_by_title : public std::binary_function<std::tr1::shared_ptr<rss_feed>, std::tr1::shared_ptr<rss_feed>, bool> {
-	sort_feeds_by_title() { }
-	bool operator()(std::tr1::shared_ptr<rss_feed> a, std::tr1::shared_ptr<rss_feed> b) {
-		return strcasecmp(a->title().c_str(), b->title().c_str()) < 0;
-	}
-};
-
-struct sort_feeds_by_articles : public std::binary_function<std::tr1::shared_ptr<rss_feed>, std::tr1::shared_ptr<rss_feed>, bool> {
-	sort_feeds_by_articles() { }
-	bool operator()(std::tr1::shared_ptr<rss_feed> a, std::tr1::shared_ptr<rss_feed> b) {
-		return a->total_item_count() < b->total_item_count();
-	}
-};
-
-struct sort_feeds_by_unread_articles : public std::binary_function<std::tr1::shared_ptr<rss_feed>, std::tr1::shared_ptr<rss_feed>, bool> {
-	sort_feeds_by_unread_articles() { }
-	bool operator()(std::tr1::shared_ptr<rss_feed> a, std::tr1::shared_ptr<rss_feed> b) {
-		return a->unread_item_count() < b->unread_item_count();
-	}
-};
-
-struct sort_feeds_by_order : public std::binary_function<std::tr1::shared_ptr<rss_feed>, std::tr1::shared_ptr<rss_feed>, bool> {
-	sort_feeds_by_order() { }
-	bool operator()(std::tr1::shared_ptr<rss_feed> a, std::tr1::shared_ptr<rss_feed> b) {
-		return a->get_order() < b->get_order();
-	}
-};
-
-
 void controller::sort_feeds() {
-	scope_mutex feedslock(&feeds_mutex);
+	std::lock_guard<std::mutex> feedslock(feeds_mutex);
 	std::vector<std::string> sortmethod_info = utils::tokenize(cfg.get_configvalue("feed-sort-order"), "-");
 	std::string sortmethod = sortmethod_info[0];
 	std::string direction = "desc";
 	if (sortmethod_info.size() > 1)
 		direction = sortmethod_info[1];
 	if (sortmethod == "none") {
-		std::stable_sort(feeds.begin(), feeds.end(), sort_feeds_by_order());
+		std::stable_sort(feeds.begin(), feeds.end(), [](std::shared_ptr<rss_feed> a, std::shared_ptr<rss_feed> b) {
+			return a->get_order() < b->get_order();
+		});
 	} else if (sortmethod == "firsttag") {
-		std::stable_sort(feeds.begin(), feeds.end(), sort_feeds_by_firsttag());
+		std::stable_sort(feeds.begin(), feeds.end(), [](std::shared_ptr<rss_feed> a, std::shared_ptr<rss_feed> b) {
+			if (a->get_firsttag().length() == 0 || b->get_firsttag().length() == 0) {
+				return a->get_firsttag().length() > b->get_firsttag().length();
+			}
+			return strcasecmp(a->get_firsttag().c_str(), b->get_firsttag().c_str()) < 0;
+		});
 	} else if (sortmethod == "title") {
-		std::stable_sort(feeds.begin(), feeds.end(), sort_feeds_by_title());
+		std::stable_sort(feeds.begin(), feeds.end(), [](std::shared_ptr<rss_feed> a, std::shared_ptr<rss_feed> b) {
+			return strcasecmp(a->title().c_str(), b->title().c_str()) < 0;
+		});
 	} else if (sortmethod == "articlecount") {
-		std::stable_sort(feeds.begin(), feeds.end(), sort_feeds_by_articles());
+		std::stable_sort(feeds.begin(), feeds.end(), [](std::shared_ptr<rss_feed> a, std::shared_ptr<rss_feed> b) {
+			return a->total_item_count() < b->total_item_count();
+		});
 	} else if (sortmethod == "unreadarticlecount") {
-		std::stable_sort(feeds.begin(), feeds.end(), sort_feeds_by_unread_articles());
+		std::stable_sort(feeds.begin(), feeds.end(), [](std::shared_ptr<rss_feed> a, std::shared_ptr<rss_feed> b) {
+			return a->unread_item_count() < b->unread_item_count();
+		});
 	}
 	if (direction == "asc") {
 		std::reverse(feeds.begin(), feeds.end());
@@ -1590,48 +1564,48 @@ void controller::dump_config(const std::string& filename) {
 	std::fstream f;
 	f.open(filename.c_str(), std::fstream::out);
 	if (f.is_open()) {
-		for (std::vector<std::string>::iterator it=configlines.begin();it!=configlines.end();++it) {
-			f << *it << std::endl;
+		for (auto line : configlines) {
+			f << line << std::endl;
 		}
 	}
 }
 
 unsigned int controller::get_pos_of_next_unread(unsigned int pos) {
-	scope_mutex feedslock(&feeds_mutex);
-	for (pos++;pos < feeds.size();pos++) {
+	std::lock_guard<std::mutex> feedslock(feeds_mutex);
+	for (pos++; pos < feeds.size(); pos++) {
 		if (feeds[pos]->unread_item_count() > 0)
 			break;
 	}
 	return pos;
 }
 
-void controller::update_flags(std::tr1::shared_ptr<rss_item> item) {
+void controller::update_flags(std::shared_ptr<rss_item> item) {
 	if (api) {
 		api->update_article_flags(item->oldflags(), item->flags(), item->guid());
 	}
 	item->update_flags();
 }
 
-std::vector<std::tr1::shared_ptr<rss_feed> > controller::get_all_feeds() { 
-	std::vector<std::tr1::shared_ptr<rss_feed> > tmpfeeds;
+std::vector<std::shared_ptr<rss_feed>> controller::get_all_feeds() {
+	std::vector<std::shared_ptr<rss_feed>> tmpfeeds;
 	{
-		scope_mutex feedslock(&feeds_mutex);
+		std::lock_guard<std::mutex> feedslock(feeds_mutex);
 		tmpfeeds = feeds;
 	}
-	return tmpfeeds; 
+	return tmpfeeds;
 }
 
-std::vector<std::tr1::shared_ptr<rss_feed> > controller::get_all_feeds_unlocked() {
+std::vector<std::shared_ptr<rss_feed>> controller::get_all_feeds_unlocked() {
 	return feeds;
 }
 
 
 unsigned int controller::get_feed_count_per_tag(const std::string& tag) {
 	unsigned int count = 0;
-	scope_mutex feedslock(&feeds_mutex);
+	std::lock_guard<std::mutex> feedslock(feeds_mutex);
 
-	for (std::vector<std::tr1::shared_ptr<rss_feed> >::const_iterator it=feeds.begin();it!=feeds.end();it++) {
-		if ((*it)->matches_tag(tag)) {
+	for (auto feed : feeds) {
+		if (feed->matches_tag(tag)) {
 			count++;
 		}
 	}
