@@ -1,8 +1,7 @@
 #include <markreadthread.h>
 #include <logger.h>
 
-namespace newsbeuter
-{
+namespace newsbeuter {
 
 markreadthread::markreadthread( ttrss_api* r_api, const std::string& guid, bool read ) :
 	_r_api( r_api ),
@@ -13,7 +12,7 @@ markreadthread::markreadthread( ttrss_api* r_api, const std::string& guid, bool
 markreadthread::~markreadthread() {
 }
 
-void markreadthread::run() {
+void markreadthread::operator()() {
 	/*
 	 * the markreadthread class handles marking a thread as read in a way that
 	 * doesn't halt the presentation of the content. this is for remote sources,
