@@ -11,6 +11,7 @@
 #include <sys/types.h>
 #include <pwd.h>
 #include <cstdlib>
+#include <thread>
 #include <signal.h>
 #include <unistd.h>
 
@@ -42,65 +43,63 @@ namespace podbeuter {
  * returns false, if that fails
  */
 bool pb_controller::setup_dirs_xdg(const char *env_home) {
-        const char *env_xdg_config;
-        const char *env_xdg_data;
-        std::string xdg_config_dir;
-        std::string xdg_data_dir;
+	const char *env_xdg_config;
+	const char *env_xdg_data;
+	std::string xdg_config_dir;
+	std::string xdg_data_dir;
 
-        env_xdg_config = ::getenv("XDG_CONFIG_HOME");
-        if (env_xdg_config) {
-                xdg_config_dir = env_xdg_config;
-        } else {
-                xdg_config_dir = env_home;
-                xdg_config_dir.append(NEWSBEUTER_PATH_SEP);
-                xdg_config_dir.append(".config");
-        }
+	env_xdg_config = ::getenv("XDG_CONFIG_HOME");
+	if (env_xdg_config) {
+		xdg_config_dir = env_xdg_config;
+	} else {
+		xdg_config_dir = env_home;
+		xdg_config_dir.append(NEWSBEUTER_PATH_SEP);
+		xdg_config_dir.append(".config");
+	}
 
-        env_xdg_data = ::getenv("XDG_DATA_HOME");
-        if (env_xdg_data) {
-                xdg_data_dir = env_xdg_data;
-        } else {
-                xdg_data_dir = env_home;
-                xdg_data_dir.append(NEWSBEUTER_PATH_SEP);
-                xdg_data_dir.append(".local");
-                xdg_data_dir.append(NEWSBEUTER_PATH_SEP);
-                xdg_data_dir.append("share");
-        }
+	env_xdg_data = ::getenv("XDG_DATA_HOME");
+	if (env_xdg_data) {
+		xdg_data_dir = env_xdg_data;
+	} else {
+		xdg_data_dir = env_home;
+		xdg_data_dir.append(NEWSBEUTER_PATH_SEP);
+		xdg_data_dir.append(".local");
+		xdg_data_dir.append(NEWSBEUTER_PATH_SEP);
+		xdg_data_dir.append("share");
+	}
 
-        xdg_config_dir.append(NEWSBEUTER_PATH_SEP);
-        xdg_config_dir.append(NEWSBEUTER_SUBDIR_XDG);
+	xdg_config_dir.append(NEWSBEUTER_PATH_SEP);
+	xdg_config_dir.append(NEWSBEUTER_SUBDIR_XDG);
 
-        xdg_data_dir.append(NEWSBEUTER_PATH_SEP);
-        xdg_data_dir.append(NEWSBEUTER_SUBDIR_XDG);
+	xdg_data_dir.append(NEWSBEUTER_PATH_SEP);
+	xdg_data_dir.append(NEWSBEUTER_SUBDIR_XDG);
 
-        if (access(xdg_config_dir.c_str(), R_OK | X_OK) != 0)
-        {
-                std::cout << utils::strprintf(_("XDG: configuration directory '%s' not accessible, using '%s' instead."), xdg_config_dir.c_str(), config_dir.c_str()) << std::endl;
-                return false;
-        }
-        if (access(xdg_data_dir.c_str(), R_OK | X_OK | W_OK) != 0)
-        {
-                std::cout << utils::strprintf(_("XDG: data directory '%s' not accessible, using '%s' instead."), xdg_data_dir.c_str(), config_dir.c_str()) << std::endl;
-                return false;
-        }
+	if (access(xdg_config_dir.c_str(), R_OK | X_OK) != 0) {
+		std::cout << utils::strprintf(_("XDG: configuration directory '%s' not accessible, using '%s' instead."), xdg_config_dir.c_str(), config_dir.c_str()) << std::endl;
+		return false;
+	}
+	if (access(xdg_data_dir.c_str(), R_OK | X_OK | W_OK) != 0) {
+		std::cout << utils::strprintf(_("XDG: data directory '%s' not accessible, using '%s' instead."), xdg_data_dir.c_str(), config_dir.c_str()) << std::endl;
+		return false;
+	}
 
-        config_dir = xdg_config_dir;
+	config_dir = xdg_config_dir;
 
-        /* in config */
-        url_file = config_dir + std::string(NEWSBEUTER_PATH_SEP) + url_file;
-        config_file = config_dir + std::string(NEWSBEUTER_PATH_SEP) + config_file;
+	/* in config */
+	url_file = config_dir + std::string(NEWSBEUTER_PATH_SEP) + url_file;
+	config_file = config_dir + std::string(NEWSBEUTER_PATH_SEP) + config_file;
 
-        /* in data */
-        cache_file = xdg_data_dir + std::string(NEWSBEUTER_PATH_SEP) + cache_file;
-        lock_file = cache_file + LOCK_SUFFIX;
-        queue_file = xdg_data_dir + std::string(NEWSBEUTER_PATH_SEP) + queue_file;
-        searchfile = utils::strprintf("%s%shistory.search", xdg_data_dir.c_str(), NEWSBEUTER_PATH_SEP);
-        cmdlinefile = utils::strprintf("%s%shistory.cmdline", xdg_data_dir.c_str(), NEWSBEUTER_PATH_SEP);
+	/* in data */
+	cache_file = xdg_data_dir + std::string(NEWSBEUTER_PATH_SEP) + cache_file;
+	lock_file = cache_file + LOCK_SUFFIX;
+	queue_file = xdg_data_dir + std::string(NEWSBEUTER_PATH_SEP) + queue_file;
+	searchfile = utils::strprintf("%s%shistory.search", xdg_data_dir.c_str(), NEWSBEUTER_PATH_SEP);
+	cmdlinefile = utils::strprintf("%s%shistory.cmdline", xdg_data_dir.c_str(), NEWSBEUTER_PATH_SEP);
 
-        return true;
+	return true;
 }
 
-pb_controller::pb_controller() : v(0), config_file("config"), queue_file("queue"), cfg(0), view_update_(true),  max_dls(1), ql(0) { 
+pb_controller::pb_controller() : v(0), config_file("config"), queue_file("queue"), cfg(0), view_update_(true),  max_dls(1), ql(0) {
 	char * cfgdir;
 	if (!(cfgdir = ::getenv("HOME"))) {
 		struct passwd * spw = ::getpwuid(::getuid());
@@ -126,7 +125,7 @@ pb_controller::pb_controller() : v(0), config_file("config"), queue_file("queue"
 	lock_file = config_dir + std::string(NEWSBEUTER_PATH_SEP) + lock_file;
 }
 
-pb_controller::~pb_controller() { 
+pb_controller::~pb_controller() {
 	delete cfg;
 }
 
@@ -141,36 +140,35 @@ void pb_controller::run(int argc, char * argv[]) {
 			continue;
 
 		switch (c) {
-			case ':':
-			case '?':
-				usage(argv[0]);
-				break;
-			case 'C':
-				config_file = optarg;
-				break;
-			case 'q':
-				queue_file = optarg;
-				break;
-			case 'a':
-				automatic_dl = true;
-				break;
-			case 'd': // this is an undocumented debug commandline option!
-				logger::getInstance().set_logfile(optarg);
-				break;
-			case 'l': // this is an undocumented debug commandline option!
-				{
-					loglevel level = static_cast<loglevel>(atoi(optarg));
-					if (level > LOG_NONE && level <= LOG_DEBUG)
-						logger::getInstance().set_loglevel(level);
-				}
-				break;
-			case 'h':
-				usage(argv[0]);
-				break;
-			default:
-				std::cout << utils::strprintf(_("%s: unknown option - %c"), argv[0], static_cast<char>(c)) << std::endl;
-				usage(argv[0]);
-				break;
+		case ':':
+		case '?':
+			usage(argv[0]);
+			break;
+		case 'C':
+			config_file = optarg;
+			break;
+		case 'q':
+			queue_file = optarg;
+			break;
+		case 'a':
+			automatic_dl = true;
+			break;
+		case 'd': // this is an undocumented debug commandline option!
+			logger::getInstance().set_logfile(optarg);
+			break;
+		case 'l': { // this is an undocumented debug commandline option!
+			loglevel level = static_cast<loglevel>(atoi(optarg));
+			if (level > LOG_NONE && level <= LOG_DEBUG)
+				logger::getInstance().set_loglevel(level);
+		}
+		break;
+		case 'h':
+			usage(argv[0]);
+			break;
+		default:
+			std::cout << utils::strprintf(_("%s: unknown option - %c"), argv[0], static_cast<char>(c)) << std::endl;
+			usage(argv[0]);
+			break;
 		}
 	} while (c != -1);
 
@@ -210,7 +208,7 @@ void pb_controller::run(int argc, char * argv[]) {
 	} catch (const configexception& ex) {
 		std::cout << ex.what() << std::endl;
 		delete colorman;
-		return;	
+		return;
 	}
 
 	if (colorman->colors_loaded())
@@ -225,17 +223,17 @@ void pb_controller::run(int argc, char * argv[]) {
 	ql->reload(downloads_);
 
 	v->set_keymap(&keys);
-	
+
 	v->run(automatic_dl);
 
 	stfl::reset();
 
 	std::cout <<  _("Cleaning up queue...");
 	std::cout.flush();
-	
+
 	ql->reload(downloads_);
 	delete ql;
-	
+
 	std::cout << _("done.") << std::endl;
 
 	utils::remove_fs_lock(lock_file);
@@ -243,10 +241,10 @@ void pb_controller::run(int argc, char * argv[]) {
 
 void pb_controller::usage(const char * argv0) {
 	std::cout << utils::strprintf(_("%s %s\nusage %s [-C <file>] [-q <file>] [-h]\n"
-				"-C <configfile> read configuration from <configfile>\n"
-				"-q <queuefile>  use <queuefile> as queue file\n"
-				"-a              start download on startup\n"
-				"-h              this help\n"), "podbeuter", PROGRAM_VERSION, argv0);
+	                                "-C <configfile> read configuration from <configfile>\n"
+	                                "-q <queuefile>  use <queuefile> as queue file\n"
+	                                "-a              start download on startup\n"
+	                                "-h              this help\n"), "podbeuter", PROGRAM_VERSION, argv0);
 	::exit(EXIT_FAILURE);
 }
 
@@ -256,11 +254,9 @@ std::string pb_controller::get_dlpath() {
 
 unsigned int pb_controller::downloads_in_progress() {
 	unsigned int count = 0;
-	if (downloads_.size() > 0) {
-		for (std::vector<download>::iterator it=downloads_.begin();it!=downloads_.end();++it) {
-			if (it->status() == DL_DOWNLOADING)
-				++count;
-		}
+	for (auto dl : downloads_) {
+		if (dl.status() == DL_DOWNLOADING)
+			++count;
 	}
 	return count;
 }
@@ -277,11 +273,9 @@ void pb_controller::reload_queue(bool remove_unplayed) {
 
 double pb_controller::get_total_kbps() {
 	double result = 0.0;
-	if (downloads_.size() > 0) {
-		for (std::vector<download>::iterator it=downloads_.begin();it!=downloads_.end();++it) {
-			if (it->status() == DL_DOWNLOADING) {
-				result += it->kbps();
-			}
+	for (auto dl : downloads_) {
+		if (dl.status() == DL_DOWNLOADING) {
+			result += dl.kbps();
 		}
 	}
 	return result;
@@ -289,10 +283,9 @@ double pb_controller::get_total_kbps() {
 
 void pb_controller::start_downloads() {
 	int dl2start = get_maxdownloads() - downloads_in_progress();
-	for (std::vector<download>::iterator it=downloads_.begin();dl2start > 0 && it!=downloads_.end();++it) {
+	for (auto it=downloads_.begin(); dl2start > 0 && it!=downloads_.end(); ++it) {
 		if (it->status() == DL_QUEUED) {
-			poddlthread * thread = new poddlthread(&(*it), cfg);
-			thread->start();
+			std::thread t {poddlthread(&(*it), cfg)};
 			--dl2start;
 		}
 	}
