@@ -36,43 +36,43 @@ void select_formaction::handle_cmdline(const std::string& cmd) {
 void select_formaction::process_operation(operation op, bool /* automatic */, std::vector<std::string> * /* args */) {
 	bool hardquit = false;
 	switch (op) {
-		case OP_QUIT:
-			value = "";
-			quit = true;
-			break;
-		case OP_HARDQUIT:
-			value = "";
-			hardquit = true;
-			break;
-		case OP_OPEN: {
-				std::string tagposname = f->get("tagposname");
-				std::istringstream posname(tagposname);
-				unsigned int pos = 0;
-				posname >> pos;
-				if (tagposname.length() > 0) {
-					switch (type) {
-					case SELECTTAG: {
-							if (pos < tags.size()) {
-								value = tags[pos];
-								quit = true;
-							}
-						}
-						break;
-					case SELECTFILTER: {
-							if (pos < filters.size()) {
-								value = filters[pos].second;
-								quit = true;
-							}
-						}
-						break;
-					default:
-						assert(0); // should never happen
-					}
+	case OP_QUIT:
+		value = "";
+		quit = true;
+		break;
+	case OP_HARDQUIT:
+		value = "";
+		hardquit = true;
+		break;
+	case OP_OPEN: {
+		std::string tagposname = f->get("tagposname");
+		std::istringstream posname(tagposname);
+		unsigned int pos = 0;
+		posname >> pos;
+		if (tagposname.length() > 0) {
+			switch (type) {
+			case SELECTTAG: {
+				if (pos < tags.size()) {
+					value = tags[pos];
+					quit = true;
 				}
 			}
 			break;
-		default:
+			case SELECTFILTER: {
+				if (pos < filters.size()) {
+					value = filters[pos].second;
+					quit = true;
+				}
+			}
 			break;
+			default:
+				assert(0); // should never happen
+			}
+		}
+	}
+	break;
+	default:
+		break;
 	}
 
 	if (hardquit) {
@@ -90,22 +90,24 @@ void select_formaction::prepare() {
 		unsigned int i=0;
 		switch (type) {
 		case SELECTTAG:
-			for (std::vector<std::string>::const_iterator it=tags.begin();it!=tags.end();++it,++i) {
-				std::string tagstr = utils::strprintf("%4u  %s (%u)", i+1, it->c_str(), v->get_ctrl()->get_feed_count_per_tag(*it));
+			for (auto tag : tags) {
+				std::string tagstr = utils::strprintf("%4u  %s (%u)", i+1, tag.c_str(), v->get_ctrl()->get_feed_count_per_tag(tag));
 				listfmt.add_line(tagstr, i);
+				i++;
 			}
 			break;
 		case SELECTFILTER:
-			for (std::vector<filter_name_expr_pair>::const_iterator it=filters.begin();it!=filters.end();++it,++i) {
-				std::string tagstr = utils::strprintf("%4u  %s", i+1, it->first.c_str());
+			for (auto filter : filters) {
+				std::string tagstr = utils::strprintf("%4u  %s", i+1, filter.first.c_str());
 				listfmt.add_line(tagstr, i);
+				i++;
 			}
 			break;
 		default:
 			assert(0);
 		}
 		f->modify("taglist", "replace_inner", listfmt.format_list());
-		
+
 		do_redraw = false;
 	}
 }
@@ -162,12 +164,12 @@ keymap_hint_entry * select_formaction::get_keymap_hint() {
 
 std::string select_formaction::title() {
 	switch (type) {
-		case SELECTTAG:
-			return _("Select Tag");
-		case SELECTFILTER:
-			return _("Select Filter");
-		default:
-			return "";
+	case SELECTTAG:
+		return _("Select Tag");
+	case SELECTFILTER:
+		return _("Select Filter");
+	default:
+		return "";
 	}
 }
 
