@@ -4,7 +4,7 @@ rm -f *.rb.log
 
 for f in *.rb ; do
 	echo "Running $f..."
-	ruby "$f" > /dev/null
+	ruby1.8 "$f" > /dev/null
 	if [ $? != 0 ] ; then
 		echo "Running test $f failed."
 		#exit 1
