@@ -2,12 +2,12 @@
 # tests the urls-source "opml" configuration option
 require 'tuitest'
 
-Kernel.system("rm -f cache")
+Kernel.system("rm -f cache cache.lock")
+
+if not ENV["OFFLINE"] then # this test doesn't work in offline mode.
 
 Tuitest.init
 verifier = Tuitest::Verifier.new("test-opmlsrc.rb.log", "RESULT-test-opmlsrc.rb.xml")
-
-
 Tuitest.run("../newsbeuter -c cache -C config-tuitest2 -u /dev/null")
 
 Tuitest.wait_until_expected_text(1, 3, "1         (0/0) http://testbed.newsbeuter.org/rss20.xml", 5000)
@@ -33,6 +33,8 @@ Tuitest.wait_until_idle
 Tuitest.close
 verifier.finish
 
-Kernel.system("rm -f cache")
+Kernel.system("rm -f cache cache.lock")
+
+end # not ENV["OFFLINE"]
 
 # EOF
