@@ -38,11 +38,11 @@ void TestNewsbeuterReload() {
 	cache * rsscache = new cache("test-cache.db", cfg);
 
 	rss_parser parser("http://testbed.newsbeuter.org/unit-test/rss.xml", rsscache, cfg, NULL);
-	std::tr1::shared_ptr<rss_feed> feed = parser.parse();
+	std::shared_ptr<rss_feed> feed = parser.parse();
 	lemon.is(feed->items().size(), 8u, "rss.xml contains 8 items");
 
 	rsscache->externalize_rssfeed(feed, false);
-	rsscache->internalize_rssfeed(feed, NULL);
+	feed = rsscache->internalize_rssfeed("http://testbed.newsbeuter.org/unit-test/rss.xml", NULL);
 	lemon.is(feed->items().size(), 8u, "feed contains 8 items after externalization/internalization");
 
 	lemon.is(feed->items()[0]->title(), "Teh Saxxi", "first item title");
@@ -54,9 +54,7 @@ void TestNewsbeuterReload() {
 
 	rsscache->externalize_rssfeed(feed, false);
 
-	std::tr1::shared_ptr<rss_feed> feed2(new rss_feed(rsscache));
-	feed2->set_rssurl("http://testbed.newsbeuter.org/unit-test/rss.xml");
-	rsscache->internalize_rssfeed(feed2, NULL);
+	std::shared_ptr<rss_feed> feed2 = rsscache->internalize_rssfeed("http://testbed.newsbeuter.org/unit-test/rss.xml", NULL);
 
 	lemon.is(feed2->items().size(), 8u, "feed2 contains 8 items after internalizaton");
 	lemon.is(feed2->items()[0]->title(), "Another Title", "feed2 first item title");
@@ -66,7 +64,7 @@ void TestNewsbeuterReload() {
 	lemon.is(feedurls.size(), 1u, "1 feed url");
 	lemon.is(feedurls[0], "http://testbed.newsbeuter.org/unit-test/rss.xml", "first feed url");
 
-	std::vector<std::tr1::shared_ptr<rss_feed> > feedv;
+	std::vector<std::shared_ptr<rss_feed>> feedv;
 	feedv.push_back(feed);
 
 	cfg->set_configvalue("cleanup-on-quit", "true");
@@ -266,7 +264,7 @@ void TestTokenizers() {
 
 	tokens = utils::tokenize("	");
 	lemon.is(tokens.size(), 0u, "tokenize of tab resulted in 0 tokens");
-	
+
 	tokens = utils::tokenize("");
 	lemon.is(tokens.size(), 0u, "tokenize of empty string resulted in 0 tokens");
 
@@ -538,7 +536,7 @@ void TestStringConversion() {
 
 	std::string s2 = utils::wstr2str(L"");
 	lemon.is(s2, "", "conversion from empty wstring to string");
-	
+
 }
 
 void TestFmtStrFormatter() {
@@ -751,7 +749,7 @@ void TestHtmlRenderer() {
 }
 
 void TestIndexPartitioning() {
-	std::vector<std::pair<unsigned int, unsigned int> > partitions = utils::partition_indexes(0, 9, 2);
+	std::vector<std::pair<unsigned int, unsigned int>> partitions = utils::partition_indexes(0, 9, 2);
 	lemon.is(partitions.size(), 2u, "partitioning of [0,9] in 2 parts produced 2 parts");
 	lemon.is(partitions[0].first, 0u, "first partition start is 0");
 	lemon.is(partitions[0].second, 4u, "first partition end is 4");
